# vmware-tca-sdk-python

VMware Telco Cloud Automation API SDK

This Python SDK help build software around the VMware Telco Cloud Automation APIs:

- VMware Telco Cloud Automation API version: 2.1.0
- SDK-Python Package version: 2.1.0



## Requirements.
Python 3.8+



## Installation & Usage

### pip install



Fetch the tar for the given TCA build, e.g. vmware_tca_sdk_python-2.1.0-buildnumber.whl
From the command line, run the

```sh

#Install
python3.8 -m pip install wheels/vmware_tca_sdk_python-2.1.0-<buildnumber>.whl  --force-reinstall
```

_(you may need to run `pip` with root permission: `sudo pip install ...`)_

 Once successfully installed, you may want to verify the installed SDK:

```sh

#List installed TCA SDK-Python packages
python3.8 -m pip list -l -v -v -v | grep -E "tca|Package|\-\-\-"
```

Now, to use the SDK, here is a sample code for reference:


```python

from tca.api.client.tca_configuration import TCAConfiguration
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.logging_manager import ConsoleLogger as CL
import tca.api.client.sdk_manager

# Initiate the basic configuration
config = TCAConfiguration()
config.set_server('https://tca_server/')
config.set_username('you@yourdomain.local')
config.set_password('********************')
config.set_verify_ssl(True)

# SSL configuration
config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"

# Initialize the TCA Hybridity Session Manager
hybridity_sessionmgr = HybriditySessionManager()
global session_manager
session_manager = hybridity_sessionmgr

# Initialize the SDK Manager
global sdk_manager
sdk_manager = SDKManager(). \
    with_configuration(tca_config). \
    with_session_manager(session_manager)

# Get the API-segment/Feature facade
vnfpkgm_api_client = sdk_manager.get_api('tca.vnfpkgm:VnfCatalogApi')

# Invoke 'vnfpkgm' specific API methods (with default headers)`
vnf_descriptors = vnfpkgm_api_client.get_all_vnf_descriptors(
    version='2.7.1',
    # Optional Headers
    accept='application/json')

#similarly other APIs
nsdm_api_client =  sdk_manager.get_api('tca.nsdm:DefaultApi')
ns_descriptors =  nsdm_api_client.get_all_ns_descriptors(
    version='2.7.1')

```



### Setuptools



Install via [Setuptools](http://pypi.python.org/pypi/setuptools).



```sh

python setup.py install --user

```

(or `sudo python setup.py install` to install the package for all users)

The sample code has been given above.

## Finding APIs and Method
To list the API Clients and the corresponding methods,

```python

# Assuming you have the SDKManager initialized

# Lists all the API clients, in a dict format: {KEY: CLIENT}.
sdk_manager.list()

# An API client can be fetched using a key obtained above.
my_api_client = sdk_manager.get_api('<key>')

# List the available methods available in the API client
my_api_client.list()

```

## Documentation for API Endpoints and Models
[docs/](./docs/*)


## Documentation For Authorization


### SOL and Caas APIs
#### x-hm-authorization
- **Type**: API key
- **API key parameter name**: x-hm-authorization
- **Location**: HTTP header

#### Active Directory
- _TBD_

### TCA Admin and Appliance Management APIs
#### HTTP Basic
- **Type**: HTTP Basic
- **API key parameter name**: x-hm-authorization
- **Location**: HTTP header

#### Active Directory (Admin)
- _TBD_


## Author
banerjees@vmware.com

