# tca.caas_v2_addon.AddonApi

All URIs are relative to */telco/api/caas/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_addon**](AddonApi.md#create_addon) | **POST** /clusters/{clusterName}/addons | API to create Addon like multus, vsphere-csi etc. on Kubernetes Cluster
[**delete_addon**](AddonApi.md#delete_addon) | **DELETE** /clusters/{clusterName}/addons/{addonName} | API to delete Addon like multus, vsphere-csi etc. on Kubernetes Cluster
[**get_addon**](AddonApi.md#get_addon) | **GET** /clusters/{clusterName}/addons/{addonName} | API to get Addon like multus, vsphere-csi etc. created on Kubernetes Cluster
[**get_addons**](AddonApi.md#get_addons) | **GET** /clusters/{clusterName}/addons | API to fetch all Addons like multus, vsphere-csi etc. created on Kubernetes Cluster
[**update_addon**](AddonApi.md#update_addon) | **PUT** /clusters/{clusterName}/addons/{addonName} | API to update Addon like multus, vsphere-csi etc. on Kubernetes Cluster

# **create_addon**
> Addon create_addon(body, tca_cp_id, cluster_name, mgmt_cluster_name=mgmt_cluster_name)

API to create Addon like multus, vsphere-csi etc. on Kubernetes Cluster

API to create Addon on Kubernetes Cluster

### Example
```python
from __future__ import print_function
import time
import tca.caas_v2_addon
from tca.caas_v2_addon.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.caas_v2_addon.AddonApi()
body = tca.caas_v2_addon.Addon() # Addon | Create Addon payload
tca_cp_id = 'tca_cp_id_example' # str | TCA-CP id of management cluster managing given cluster
cluster_name = 'cluster_name_example' # str | Name of cluster on which addon needs to be created
mgmt_cluster_name = 'mgmt_cluster_name_example' # str | Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  (optional)

try:
    # API to create Addon like multus, vsphere-csi etc. on Kubernetes Cluster
    api_response = api_instance.create_addon(body, tca_cp_id, cluster_name, mgmt_cluster_name=mgmt_cluster_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AddonApi->create_addon: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Addon**](Addon.md)| Create Addon payload | 
 **tca_cp_id** | **str**| TCA-CP id of management cluster managing given cluster | 
 **cluster_name** | **str**| Name of cluster on which addon needs to be created | 
 **mgmt_cluster_name** | **str**| Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  | [optional] 

### Return type

[**Addon**](Addon.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json, application/x-yaml
 - **Accept**: application/json, application/x-yaml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_addon**
> Addon delete_addon(cluster_name, addon_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name)

API to delete Addon like multus, vsphere-csi etc. on Kubernetes Cluster

API to delete Addon on Kubernetes Cluster

### Example
```python
from __future__ import print_function
import time
import tca.caas_v2_addon
from tca.caas_v2_addon.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.caas_v2_addon.AddonApi()
cluster_name = 'cluster_name_example' # str | Name of cluster where addon is created
addon_name = 'addon_name_example' # str | Name of addon
tca_cp_id = 'tca_cp_id_example' # str | TCA-CP id of management cluster managing given cluster
mgmt_cluster_name = 'mgmt_cluster_name_example' # str | Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  (optional)

try:
    # API to delete Addon like multus, vsphere-csi etc. on Kubernetes Cluster
    api_response = api_instance.delete_addon(cluster_name, addon_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AddonApi->delete_addon: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **cluster_name** | **str**| Name of cluster where addon is created | 
 **addon_name** | **str**| Name of addon | 
 **tca_cp_id** | **str**| TCA-CP id of management cluster managing given cluster | 
 **mgmt_cluster_name** | **str**| Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  | [optional] 

### Return type

[**Addon**](Addon.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/x-yaml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_addon**
> Addon get_addon(cluster_name, addon_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name)

API to get Addon like multus, vsphere-csi etc. created on Kubernetes Cluster

API to get Addon on Kubernetes Cluster

### Example
```python
from __future__ import print_function
import time
import tca.caas_v2_addon
from tca.caas_v2_addon.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.caas_v2_addon.AddonApi()
cluster_name = 'cluster_name_example' # str | Name of cluster where addon is created
addon_name = 'addon_name_example' # str | Name of addon
tca_cp_id = 'tca_cp_id_example' # str | TCA-CP id of management cluster managing given cluster
mgmt_cluster_name = 'mgmt_cluster_name_example' # str | Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  (optional)

try:
    # API to get Addon like multus, vsphere-csi etc. created on Kubernetes Cluster
    api_response = api_instance.get_addon(cluster_name, addon_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AddonApi->get_addon: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **cluster_name** | **str**| Name of cluster where addon is created | 
 **addon_name** | **str**| Name of addon | 
 **tca_cp_id** | **str**| TCA-CP id of management cluster managing given cluster | 
 **mgmt_cluster_name** | **str**| Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  | [optional] 

### Return type

[**Addon**](Addon.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/x-yaml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_addons**
> AddonList get_addons(cluster_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name, sort=sort, nextpage_opaque_marker=nextpage_opaque_marker)

API to fetch all Addons like multus, vsphere-csi etc. created on Kubernetes Cluster

API to fetch all Addons on Kubernetes Cluster

### Example
```python
from __future__ import print_function
import time
import tca.caas_v2_addon
from tca.caas_v2_addon.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.caas_v2_addon.AddonApi()
cluster_name = 'cluster_name_example' # str | Name of cluster where addons are created
tca_cp_id = 'tca_cp_id_example' # str | TCA-CP id of management cluster managing given cluster
mgmt_cluster_name = 'mgmt_cluster_name_example' # str | Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  (optional)
sort = 'sort_example' # str | Attribute based sorting expression. (optional)
nextpage_opaque_marker = 'nextpage_opaque_marker_example' # str | Marker to obtain the next page of a paged response. If not present, API will return first page of response with page size 10. (optional)

try:
    # API to fetch all Addons like multus, vsphere-csi etc. created on Kubernetes Cluster
    api_response = api_instance.get_addons(cluster_name, tca_cp_id, mgmt_cluster_name=mgmt_cluster_name, sort=sort, nextpage_opaque_marker=nextpage_opaque_marker)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AddonApi->get_addons: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **cluster_name** | **str**| Name of cluster where addons are created | 
 **tca_cp_id** | **str**| TCA-CP id of management cluster managing given cluster | 
 **mgmt_cluster_name** | **str**| Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  | [optional] 
 **sort** | **str**| Attribute based sorting expression. | [optional] 
 **nextpage_opaque_marker** | **str**| Marker to obtain the next page of a paged response. If not present, API will return first page of response with page size 10. | [optional] 

### Return type

[**AddonList**](AddonList.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json, application/x-yaml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_addon**
> Addon update_addon(body, tca_cp_id, cluster_name, addon_name, mgmt_cluster_name=mgmt_cluster_name)

API to update Addon like multus, vsphere-csi etc. on Kubernetes Cluster

API to update Addon on Kubernetes Cluster

### Example
```python
from __future__ import print_function
import time
import tca.caas_v2_addon
from tca.caas_v2_addon.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.caas_v2_addon.AddonApi()
body = tca.caas_v2_addon.Addon() # Addon | Update Addon payload. Only spec can be updated
tca_cp_id = 'tca_cp_id_example' # str | TCA-CP id of management cluster managing given cluster
cluster_name = 'cluster_name_example' # str | Name of cluster on which addon needs to be updated
addon_name = 'addon_name_example' # str | Name of addon which needs to be updated
mgmt_cluster_name = 'mgmt_cluster_name_example' # str | Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  (optional)

try:
    # API to update Addon like multus, vsphere-csi etc. on Kubernetes Cluster
    api_response = api_instance.update_addon(body, tca_cp_id, cluster_name, addon_name, mgmt_cluster_name=mgmt_cluster_name)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AddonApi->update_addon: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**Addon**](Addon.md)| Update Addon payload. Only spec can be updated | 
 **tca_cp_id** | **str**| TCA-CP id of management cluster managing given cluster | 
 **cluster_name** | **str**| Name of cluster on which addon needs to be updated | 
 **addon_name** | **str**| Name of addon which needs to be updated | 
 **mgmt_cluster_name** | **str**| Name of management cluster of the given cluster. If given cluster is management cluster, this is not required  | [optional] 

### Return type

[**Addon**](Addon.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json, application/x-yaml
 - **Accept**: application/json, application/x-yaml

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

