# tca.vnfpkgm.DefaultApi

All URIs are relative to */telco/api/vnfpkgm/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_vnfpkgm_version_info**](DefaultApi.md#get_vnfpkgm_version_info) | **GET** /api_versions | Retrieve API version information
[**onboarded_vnf_packages_vnfd_id_vnfd_get**](DefaultApi.md#onboarded_vnf_packages_vnfd_id_vnfd_get) | **GET** /onboarded_vnf_packages/{vnfdId}/vnfd | 

# **get_vnfpkgm_version_info**
> ApiVersionInformation get_vnfpkgm_version_info(version)

Retrieve API version information

The GET method reads API version information. This method shall follow the provisions specified in table 4.6.3.3.3.2-1 for request and response data structures, and response codes. URI query parameters are not supported. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.DefaultApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 

try:
    # Retrieve API version information
    api_response = api_instance.get_vnfpkgm_version_info(version)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->get_vnfpkgm_version_info: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 

### Return type

[**ApiVersionInformation**](ApiVersionInformation.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **onboarded_vnf_packages_vnfd_id_vnfd_get**
> onboarded_vnf_packages_vnfd_id_vnfd_get(vnfd_id, accept, version, authorization=authorization, include_signatures=include_signatures)



Query VNF Package Info The GET method reads the content of the VNFD within a VNF package. The VNFD is implemented as a collection of one or more files. A ZIP archive embedding these files shall be returned when reading this resource. The default format of the ZIP archive shall be the one specified in ETSI GS NFV-SOL 004 where only the files representing the VNFD and information needed to navigate the ZIP archive and to identify the file that is the entry point for parsing the VNFD, and, if requested, further security information are included. This means that the structure of the ZIP archive shall correspond to the directory structure used in the VNF package and that the archive shall contain the following files from the package: *   TOSCA.meta (if available in the package) *   The main TOSCA definitions YAML file (either as referenced from TOSCA.meta     or available as a file with the extension \".yml\" or \".yaml\" from the root of the archive) *   Every component of the VNFD referenced (recursively) from the main TOSCA definitions YAML file *   The related security information, if the \"include_signatures\" URI parameter is provided, as follows:     -   the manifest file     -   the singleton certificate file in the root of the VNF package (if available in the package)     -   the signing certificates of the individual files included in the ZIP archive (if available in the package)     -   the signatures of the individual files (if available in the package) Three examples are provided below. NOTE:   These examples do not show the security related files. EXAMPLE 1:  Assuming a request is sent for the following VNF package             (as described in clause A.1 in ETSI GS NFV-SOL 004):             !------TOSCA-Metadata                     !-----  TOSCA.meta (metadata for navigating the ZIP file)             !------Definitions                     !-----  MRF.yaml (main VNFD file)                     !-----  OtherTemplates (e.g. type definitions, referenced by the main VNFD file)             !------Files                     !-----  ChangeLog.txt                     !-----  image(s)                     !-----  other artifacts             !------Tests                     !-----  file(s)             !------Licenses                     !-----  file(s)             !------Scripts                     !-----  install.sh             !----- MRF.mf              The NFVO will return a ZIP file of the following format:             !------TOSCA-Metadata                     !----- TOSCA.meta             !------Definitions                     !----- MRF.yaml                     !----- OtherTemplates  EXAMPLE 2:  Assuming a request is sent for the following VNF package             (a VNF package without a TOSCA-Metadata directory, as             described in clause A.2 in ETSI GS NFV-SOL 004):             !------MRF.yaml (main VNFD file)             !------MRF.mf             !------ChangeLog.txt             !------Tests                     !----- file(s)             !------Licenses                     !----- file(s)             !------Artifacts                     !----- install.sh                     !----- start.yang              The NFVO will return a ZIP file of the following format:             !------MRF.yaml  EXAMPLE 3:  Assuming a request is sent for the following VNF package             (a VNF package with the YANG VNFD without a TOSCA-Metadata directory,             as described in clause A.3 in ETSI GS NFV SOL 004):             !----CompanyVNFD.yaml             !----CompanyVNFD.xml             !----CompanyVNFD.mf             !----ChangeLog.txt             !-----Files             !-----Instance Data Files                     !---- start.xml             !-----Licenses             !-----Scripts                     !----- install.sh              The NFVO will return a ZIP file of the following format:             !----CompanyVNFD.yaml             !----CompanyVNFD.xml    (indicated in the yang_definitions metadata in CompanyVNFD.yaml)  This method shall follow the provisions specified in the tables 10.4.4.3.2-1 and 10.4.4.3.2-2 for URI query parameters, request and response data structures, nd response codes. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.DefaultApi()
vnfd_id = 'vnfd_id_example' # str | Identifier of the VNFD and the VNF package. The identifier is allocated by the VNF provider. This identifier can be retrieved from the \"vnfdId\" attribute in the VnfPackageOnboardingNotification or VnfPackageChangeNotification. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Permitted values: \"text/plain\" and/or \"application/zip\" Reference: IETF RFC 7231 
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235  (optional)
include_signatures = 'include_signatures_example' # str | If this parameter is provided, the NFVO shall include in the ZIP archive the security information as specified above. This URI query parameter is a flag, i.e. it shall have no value. The NFVO shall support this parameter.  (optional)

try:
    api_instance.onboarded_vnf_packages_vnfd_id_vnfd_get(vnfd_id, accept, version, authorization=authorization, include_signatures=include_signatures)
except ApiException as e:
    print("Exception when calling DefaultApi->onboarded_vnf_packages_vnfd_id_vnfd_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vnfd_id** | **str**| Identifier of the VNFD and the VNF package. The identifier is allocated by the VNF provider. This identifier can be retrieved from the \&quot;vnfdId\&quot; attribute in the VnfPackageOnboardingNotification or VnfPackageChangeNotification.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Permitted values: \&quot;text/plain\&quot; and/or \&quot;application/zip\&quot; Reference: IETF RFC 7231  | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235  | [optional] 
 **include_signatures** | **str**| If this parameter is provided, the NFVO shall include in the ZIP archive the security information as specified above. This URI query parameter is a flag, i.e. it shall have no value. The NFVO shall support this parameter.  | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

