# tca.vnfpkgm.VnfCatalogApi

All URIs are relative to */telco/api/vnfpkgm/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_vnf_descriptor**](VnfCatalogApi.md#create_vnf_descriptor) | **POST** /vnf_packages | Create a new individual VNF package resource.
[**delete_vnf_descriptor**](VnfCatalogApi.md#delete_vnf_descriptor) | **DELETE** /vnf_packages/{vnfPkgId} | Delete an individual VNF package.
[**download_vnf_descriptor**](VnfCatalogApi.md#download_vnf_descriptor) | **GET** /vnf_packages/{vnfPkgId}/package_content | Fetch an on-boarded VNF package.
[**get_all_vnf_descriptors**](VnfCatalogApi.md#get_all_vnf_descriptors) | **GET** /vnf_packages | Query VNF packages information.
[**get_vnf_descriptor**](VnfCatalogApi.md#get_vnf_descriptor) | **GET** /vnf_packages/{vnfPkgId} | Read information about an individual VNF package.
[**get_vnfd_model**](VnfCatalogApi.md#get_vnfd_model) | **GET** /vnf_packages/{vnfPkgId}/vnfd | Read VNFD of an on-boarded VNF package.
[**subscriptions_get**](VnfCatalogApi.md#subscriptions_get) | **GET** /subscriptions | Query multiple subscriptions.
[**subscriptions_post**](VnfCatalogApi.md#subscriptions_post) | **POST** /subscriptions | Subscribe to notifications related to on-boarding and/or changes of VNF packages.
[**subscriptions_subscription_id_delete**](VnfCatalogApi.md#subscriptions_subscription_id_delete) | **DELETE** /subscriptions/{subscriptionId} | Terminate a subscription.
[**subscriptions_subscription_id_get**](VnfCatalogApi.md#subscriptions_subscription_id_get) | **GET** /subscriptions/{subscriptionId} | Read an individual subscription resource.
[**update_vnf_catalog**](VnfCatalogApi.md#update_vnf_catalog) | **PATCH** /vnf_packages/{vnfPkgId} | Update information about an individual VNF package.
[**upload_vnf_descriptor**](VnfCatalogApi.md#upload_vnf_descriptor) | **PUT** /vnf_packages/{vnfPkgId}/package_content | Upload a VNF package by providing the content of the VNF package.

# **create_vnf_descriptor**
> VnfPkgInfo create_vnf_descriptor(body, version, accept, content_type, authorization=authorization)

Create a new individual VNF package resource.

The POST method creates a new individual VNF package resource. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
body = tca.vnfpkgm.CreateVnfPkgInfoRequest() # CreateVnfPkgInfoRequest | IndividualVNF package resource creation parameters, as defined in clause 9.5.2.2

version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
content_type = 'content_type_example' # str | The MIME type of the body of the request. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Create a new individual VNF package resource.
    api_response = api_instance.create_vnf_descriptor(body, version, accept, content_type, authorization=authorization)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->create_vnf_descriptor: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**CreateVnfPkgInfoRequest**](CreateVnfPkgInfoRequest.md)| IndividualVNF package resource creation parameters, as defined in clause 9.5.2.2
 | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **content_type** | **str**| The MIME type of the body of the request. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

[**VnfPkgInfo**](VnfPkgInfo.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: */*
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_vnf_descriptor**
> delete_vnf_descriptor(vnf_pkg_id, version, authorization=authorization)

Delete an individual VNF package.

The DELETE method deletes an individual VNF Package resource. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the VNF package. The identifier is allocated by the NFVO.   
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Delete an individual VNF package.
    api_instance.delete_vnf_descriptor(vnf_pkg_id, version, authorization=authorization)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->delete_vnf_descriptor: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vnf_pkg_id** | **str**| Identifier of the VNF package. The identifier is allocated by the NFVO.    | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **download_vnf_descriptor**
> download_vnf_descriptor(version, vnf_pkg_id, accept, authorization=authorization, range=range)

Fetch an on-boarded VNF package.

The GET method fetches the content of a VNF package identified by the VNF package identifier allocated by the NFVO. The content of the package is provided as onboarded, i.e. depending on the security option used, the CSAR or the CSAR wrapped in a ZIP archive together with an external signature is returned, as defined in clause 5.1 of ETSI GS NFV-SOL 004 [5]. NOTE: Information about the applicable security option can be obtained by evaluating the \"packageSecurityOption\" attribute in the \"VnfPkgInfo\" structure. This method shall follow the provisions specified in the Tables 9.4.5.3.2-1 and 9.4.5.3.2-2 for URI query parameters, request and response data structures, and response codes. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)
range = 'range_example' # str | The request may contain a \"Range\" HTTP header to obtain single range of bytes from the VNF package file. This can be used to continue an aborted transmission. If the NFVO does not support range requests, it should return the whole file with a 200 OK response instead.  (optional)

try:
    # Fetch an on-boarded VNF package.
    api_instance.download_vnf_descriptor(version, vnf_pkg_id, accept, authorization=authorization, range=range)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->download_vnf_descriptor: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **vnf_pkg_id** | **str**| Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO.  | 
 **accept** | **str**| Content-Types that are acceptable for the response.  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 
 **range** | **str**| The request may contain a \&quot;Range\&quot; HTTP header to obtain single range of bytes from the VNF package file. This can be used to continue an aborted transmission. If the NFVO does not support range requests, it should return the whole file with a 200 OK response instead.  | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/zip

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_all_vnf_descriptors**
> list[VnfPkgInfo] get_all_vnf_descriptors(version, accept, authorization=authorization, filter=filter, all_fields=all_fields, fields=fields, exclude_fields=exclude_fields, exclude_default=exclude_default, nextpage_opaque_marker=nextpage_opaque_marker)

Query VNF packages information.

The GET method queries the information of the VNF packages matching the filter. This method shall follow the provisions specified in the  Tables 9.4.2.3.2-1 and 9.4.2.3.2-2 for URI query parameters, request and response data structures, and response codes. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)
filter = 'filter_example' # str | Attribute-based filtering expression according to clause 5.2 of ETSI GS NFV SOL 013. The NFVO shall support receiving this parameter as part of the URI query string. The OSS/BSS may supply this parameter. All attribute names that appear in the VnfPkgInfo and in data types referenced from it shall be supported by the NFVO in the filter expression.  (optional)
all_fields = 'all_fields_example' # str | Include all complex attributes in the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO shall support this parameter.  (optional)
fields = 'fields_example' # str | Complex attributes to be included into the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO should support this parameter.  (optional)
exclude_fields = 'exclude_fields_example' # str | Complex attributes to be excluded from the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO should support this parameter.  (optional)
exclude_default = 'exclude_default_example' # str | Indicates to exclude the following complex attributes from the response. See clause 5.3 of ETSI GS NFV-SOL 013 for details. The NFVO shall support this parameter. The following attributes shall be excluded from the VnfPkgInfo structure in the response body if this parameter is provided, or none of the parameters \"all_fields,\" \"fields\", \"exclude_fields\", \"exclude_default\" are provided: - softwareImages - additionalArtifacts - userDefinedData - checksum - onboardingFailureDetails  (optional)
nextpage_opaque_marker = 'nextpage_opaque_marker_example' # str | Marker to obtain the next page of a paged response. Shall be supported by the NFVO if the NFVO supports alternative 2 (paging) according to clause 5.4.2.1 of ETSI GS NFV SOL 013 for this resource.  (optional)

try:
    # Query VNF packages information.
    api_response = api_instance.get_all_vnf_descriptors(version, accept, authorization=authorization, filter=filter, all_fields=all_fields, fields=fields, exclude_fields=exclude_fields, exclude_default=exclude_default, nextpage_opaque_marker=nextpage_opaque_marker)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->get_all_vnf_descriptors: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 
 **filter** | **str**| Attribute-based filtering expression according to clause 5.2 of ETSI GS NFV SOL 013. The NFVO shall support receiving this parameter as part of the URI query string. The OSS/BSS may supply this parameter. All attribute names that appear in the VnfPkgInfo and in data types referenced from it shall be supported by the NFVO in the filter expression.  | [optional] 
 **all_fields** | **str**| Include all complex attributes in the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO shall support this parameter.  | [optional] 
 **fields** | **str**| Complex attributes to be included into the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO should support this parameter.  | [optional] 
 **exclude_fields** | **str**| Complex attributes to be excluded from the response. See clause 5.3 of ETSI GS NFV SOL 013 for details. The NFVO should support this parameter.  | [optional] 
 **exclude_default** | **str**| Indicates to exclude the following complex attributes from the response. See clause 5.3 of ETSI GS NFV-SOL 013 for details. The NFVO shall support this parameter. The following attributes shall be excluded from the VnfPkgInfo structure in the response body if this parameter is provided, or none of the parameters \&quot;all_fields,\&quot; \&quot;fields\&quot;, \&quot;exclude_fields\&quot;, \&quot;exclude_default\&quot; are provided: - softwareImages - additionalArtifacts - userDefinedData - checksum - onboardingFailureDetails  | [optional] 
 **nextpage_opaque_marker** | **str**| Marker to obtain the next page of a paged response. Shall be supported by the NFVO if the NFVO supports alternative 2 (paging) according to clause 5.4.2.1 of ETSI GS NFV SOL 013 for this resource.  | [optional] 

### Return type

[**list[VnfPkgInfo]**](VnfPkgInfo.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_vnf_descriptor**
> VnfPkgInfo get_vnf_descriptor(vnf_pkg_id, version, accept, authorization=authorization)

Read information about an individual VNF package.

The GET method reads the information of a VNF package. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the VNF package. The identifier is allocated by the NFVO.   
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Read information about an individual VNF package.
    api_response = api_instance.get_vnf_descriptor(vnf_pkg_id, version, accept, authorization=authorization)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->get_vnf_descriptor: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **vnf_pkg_id** | **str**| Identifier of the VNF package. The identifier is allocated by the NFVO.    | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

[**VnfPkgInfo**](VnfPkgInfo.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_vnfd_model**
> Vnfd get_vnfd_model(version, vnf_pkg_id, accept, authorization=authorization, include_signatures=include_signatures)

Read VNFD of an on-boarded VNF package.

The GET method reads the content of the VNFD within a VNF package. The default format of the ZIP archive shall be the one specified in ETSI GS NFV-SOL 004 [5] where only the files representing the VNFD and information necessary to navigate the ZIP file and to identify the file that is the entry point for parsing the VNFD and (if requested) further security information are included. This means that the structure of the ZIP archive shall correspond to the directory structure used in the VNF package and that the archive shall contain the following files from the package:  - TOSCA.meta (if available in the package).  - The main TOSCA definitions YAML file (either as referenced from TOSCA.meta or available as a file with the extension \".yml\" or \".yaml\" from the root of the archive). Every component of the VNFD referenced (recursively) from the main TOSCA definitions YAML file.  -  The related security information, if the \"include_signatures\" URI parameter is provided, as follows: - the manifest file; - the singleton certificate file in the root of the VNF package (if available in the package); - the signing certificates of the individual files included in the ZIP archive (if available in the package); - the signatures of the individual files (if available in the package). 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO. This identifier can be retrieved from the \"vnfPkgId\" attribute in the VnfPackageOnboardingNotification or VnfPackageChangeNotification. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)
include_signatures = 'include_signatures_example' # str | If this parameter is provided, the NFVO shall include in the ZIP archive the security information as specified above. This URI query parameter is a flag, i.e. it shall have no value. The NFVO shall support this parameter.  (optional)

try:
    # Read VNFD of an on-boarded VNF package.
    api_response = api_instance.get_vnfd_model(version, vnf_pkg_id, accept, authorization=authorization, include_signatures=include_signatures)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->get_vnfd_model: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **vnf_pkg_id** | **str**| Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO. This identifier can be retrieved from the \&quot;vnfPkgId\&quot; attribute in the VnfPackageOnboardingNotification or VnfPackageChangeNotification.  | 
 **accept** | **str**| Content-Types that are acceptable for the response.  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 
 **include_signatures** | **str**| If this parameter is provided, the NFVO shall include in the ZIP archive the security information as specified above. This URI query parameter is a flag, i.e. it shall have no value. The NFVO shall support this parameter.  | [optional] 

### Return type

[**Vnfd**](Vnfd.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscriptions_get**
> list[PkgmSubscription] subscriptions_get(version, accept, authorization=authorization, filter=filter, nextpage_opaque_marker=nextpage_opaque_marker)

Query multiple subscriptions.

The GET method queries the list of active subscriptions of the functional block that invokes the method. It can be used e.g. for resynchronization after error situations. This method shall follow the provisions specified in the Tables 9.4.8.3.2-1 and 9.4.8.3.2-2 for URI query parameters, request and response data structures, and response codes. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)
filter = 'filter_example' # str | Attribute-based filtering expression according to clause 5.2 of ETSI GS NFV SOL 013. The NFVO shall support receiving this filtering parameter as part of the URI query string. The OSS/BSS may supply this filtering parameter. All attribute names that appear in the PkgmSubscription and in data types referenced from it shall be supported by the NFVO in the filtering expression  (optional)
nextpage_opaque_marker = 'nextpage_opaque_marker_example' # str | Marker to obtain the next page of a paged response. Shall be supported by the NFVO if the NFVO supports alternative 2 (paging) according to clause 5.4.2.1 of ETSI GS NFV-SOL 013 for this resource.  (optional)

try:
    # Query multiple subscriptions.
    api_response = api_instance.subscriptions_get(version, accept, authorization=authorization, filter=filter, nextpage_opaque_marker=nextpage_opaque_marker)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->subscriptions_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 
 **filter** | **str**| Attribute-based filtering expression according to clause 5.2 of ETSI GS NFV SOL 013. The NFVO shall support receiving this filtering parameter as part of the URI query string. The OSS/BSS may supply this filtering parameter. All attribute names that appear in the PkgmSubscription and in data types referenced from it shall be supported by the NFVO in the filtering expression  | [optional] 
 **nextpage_opaque_marker** | **str**| Marker to obtain the next page of a paged response. Shall be supported by the NFVO if the NFVO supports alternative 2 (paging) according to clause 5.4.2.1 of ETSI GS NFV-SOL 013 for this resource.  | [optional] 

### Return type

[**list[PkgmSubscription]**](PkgmSubscription.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscriptions_post**
> PkgmSubscription subscriptions_post(body, version, accept, content_type, authorization=authorization)

Subscribe to notifications related to on-boarding and/or changes of VNF packages.

The POST method creates a new subscription. This method shall follow the provisions specified in the Tables 9.4.8.3.1-1 and 9.4.8.3.1-2 for URI query parameters, request and response data structures, and response codes. As the result of successfully executing this method, a new \"Individual subscription\" resource shall exist as defined in clause 9.4.9. This method shall not trigger any notification. Creation of two subscription resources with the same callbackURI and the same filter can result in performance degradation and will provide duplicates of notifications to the OSS, and might make sense only in very rare use cases. Consequently, the NFVO may either allow creating a subscription resource if another subscription resource with the same filter and callbackUri already exists (in which case it shall return the \"201 Created\" response code), or may decide to not create a duplicate subscription resource (in which case it shall return a \"303 See Other\" response code referencing the existing subscription resource with the same filter and callbackUri). 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
body = tca.vnfpkgm.PkgmSubscriptionRequest() # PkgmSubscriptionRequest | Details of the subscription to be created.

version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
content_type = 'content_type_example' # str | The MIME type of the body of the request. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Subscribe to notifications related to on-boarding and/or changes of VNF packages.
    api_response = api_instance.subscriptions_post(body, version, accept, content_type, authorization=authorization)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->subscriptions_post: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**PkgmSubscriptionRequest**](PkgmSubscriptionRequest.md)| Details of the subscription to be created.
 | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **content_type** | **str**| The MIME type of the body of the request. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

[**PkgmSubscription**](PkgmSubscription.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: */*
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscriptions_subscription_id_delete**
> subscriptions_subscription_id_delete(subscription_id, version, authorization=authorization)

Terminate a subscription.

The DELETE method terminates an individual subscription. This method shall follow the provisions specified in the Tables 9.4.9.3.5-1 and 9.4.9.3.5-2 for URI query parameters, request and response data structures, and response codes. As the result of successfully executing this method, the \"Individual subscription\" resource shall not exist any longer. This means that no notifications for that subscription shall be sent to the formerly-subscribed API consumer. NOTE: Due to race conditions, some notifications might still be received by the formerly-subscribed API consumer for a certain time period after the deletion. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
subscription_id = 'subscription_id_example' # str | Identifier of this subscription. This identifier can be retrieved from the resource referenced by the \"Location\" HTTP header in the response to a POST request creating a new subscription resource. It can also be retrieved from the \"id\" attribute in the payload body of that response. 
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Terminate a subscription.
    api_instance.subscriptions_subscription_id_delete(subscription_id, version, authorization=authorization)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->subscriptions_subscription_id_delete: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subscription_id** | **str**| Identifier of this subscription. This identifier can be retrieved from the resource referenced by the \&quot;Location\&quot; HTTP header in the response to a POST request creating a new subscription resource. It can also be retrieved from the \&quot;id\&quot; attribute in the payload body of that response.  | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscriptions_subscription_id_get**
> PkgmSubscription subscriptions_subscription_id_get(subscription_id, version, accept, authorization=authorization)

Read an individual subscription resource.

Query Subscription Information The GET method reads an individual subscription. 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
subscription_id = 'subscription_id_example' # str | Identifier of this subscription. This identifier can be retrieved from the resource referenced by the \"Location\" HTTP header in the response to a POST request creating a new subscription resource. It can also be retrieved from the \"id\" attribute in the payload body of that response. 
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. Reference: IETF RFC 7231 
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Read an individual subscription resource.
    api_response = api_instance.subscriptions_subscription_id_get(subscription_id, version, accept, authorization=authorization)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->subscriptions_subscription_id_get: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subscription_id** | **str**| Identifier of this subscription. This identifier can be retrieved from the resource referenced by the \&quot;Location\&quot; HTTP header in the response to a POST request creating a new subscription resource. It can also be retrieved from the \&quot;id\&quot; attribute in the payload body of that response.  | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response. Reference: IETF RFC 7231  | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

[**PkgmSubscription**](PkgmSubscription.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_vnf_catalog**
> object update_vnf_catalog(body, version, content_type, vnf_pkg_id, authorization=authorization)

Update information about an individual VNF package.

\"The PATCH method updates the information of a VNF package.\" \"This method shall follow the provisions specified in the  Tables 9.4.3.3.4-1 and 9.4.3.3.4-2 for URI query parameters, request and response data structures, and response codes.\" 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
body = tca.vnfpkgm.VnfPkgInfoModifications() # VnfPkgInfoModifications | Parameters for VNF package information modifications.

version = 'version_example' # str | Version of the API requested to use when responding to this request. 
content_type = 'content_type_example' # str | The MIME type of the body of the request. Reference: IETF RFC 7231 
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the VNF package. The identifier is allocated by the NFVO.   
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Update information about an individual VNF package.
    api_response = api_instance.update_vnf_catalog(body, version, content_type, vnf_pkg_id, authorization=authorization)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->update_vnf_catalog: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**VnfPkgInfoModifications**](VnfPkgInfoModifications.md)| Parameters for VNF package information modifications.
 | 
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **content_type** | **str**| The MIME type of the body of the request. Reference: IETF RFC 7231  | 
 **vnf_pkg_id** | **str**| Identifier of the VNF package. The identifier is allocated by the NFVO.    | 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

**object**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: */*
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **upload_vnf_descriptor**
> upload_vnf_descriptor(version, accept, vnf_pkg_id, file=file, authorization=authorization)

Upload a VNF package by providing the content of the VNF package.

The PUT method uploads the content of a VNF package. This method shall follow the provisions specified in the  Tables 9.4.5.3.3-1 and 9.4.5.3.3-2 for URI query parameters, request and response data structures, and response codes. Upon start of the upload of the package, the NFVO shall set the \"onboardingState\" attribute in the \"VnfPkgInfo\" structure to \"UPLOADING\". Upon successful upload of the package, if the package references external artifacts, the NFVO shall obtain the external artifacts. Subsequently, upon success, the NFVO shall set that attribute to \"PROCESSING\" and shall process the package, which shall include checking package consistency. Upon successful processing, the NFVO shall set the \"onboardingState\" attribute to \"ONBOARDED\". If an error occurs during uploading the package, downloading the external artifacts or processing the package, the NFVO shall set the \"onboardingState\" attribute to \"ERROR\" and shall populate the \"onboardingFailureDetails\" attribute in \"VnfPkgInfo\". 

### Example
```python
from __future__ import print_function
import time
import tca.vnfpkgm
from tca.vnfpkgm.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = tca.vnfpkgm.VnfCatalogApi()
version = 'version_example' # str | Version of the API requested to use when responding to this request. 
accept = 'accept_example' # str | Content-Types that are acceptable for the response. 
vnf_pkg_id = 'vnf_pkg_id_example' # str | Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO. 
file = 'file_example' # str |  (optional)
authorization = 'authorization_example' # str | The authorization token for the request. Reference: IETF RFC 7235.  (optional)

try:
    # Upload a VNF package by providing the content of the VNF package.
    api_instance.upload_vnf_descriptor(version, accept, vnf_pkg_id, file=file, authorization=authorization)
except ApiException as e:
    print("Exception when calling VnfCatalogApi->upload_vnf_descriptor: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **version** | **str**| Version of the API requested to use when responding to this request.  | 
 **accept** | **str**| Content-Types that are acceptable for the response.  | 
 **vnf_pkg_id** | **str**| Identifier of the on-boarded VNF package. The identifier is allocated by the NFVO.  | 
 **file** | **str**|  | [optional] 
 **authorization** | **str**| The authorization token for the request. Reference: IETF RFC 7235.  | [optional] 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: */*

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

