"""
# Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
# VMware Confidential
Author: banerjees@vmware.com
"""

from tca.api.client.configuration import Configuration
from tca.api.client.rest import RESTClientObject
from tca.api.client import __package_dict__
from tca.api.client import __api_client_dict__
from tca.api.client import __configuration_dict__

class SDKManager(object):
    """
    Manager for TCA API SDK-Python
    """
    def __init__(self):
        self.configuration = None
        self.session_manager = None

    '''
    '''
    def with_configuration(self, configuration):
        if configuration is None:
            raise Exception("Cannot set configuration that is 'None'")
        self.configuration = configuration

        if self.session_manager is not None:
            self.session_manager.set_configuration(configuration)
            self.configuration.set_session_manager(self.session_manager)

        return self

    '''
    '''
    def with_session_manager(self, session_manager):
        if session_manager is None:
            raise Exception("Cannot set session_manager that is 'None'")
        self.session_manager = session_manager

        if self.configuration is not None:
            self.configuration.set_session_manager(session_manager)
            self.session_manager.set_configuration(self.configuration)
        return self

    '''
    '''
    def get_api(self, api_name, filter="", **kwargs):
        #TODO Ensure self.configuration is not None
        if api_name not in __package_dict__.keys():
            raise Exception("No API client found with id: "+api_name)
        module_name = api_name.split(sep=':')[0]
        return __package_dict__[api_name](
            __api_client_dict__[module_name](
                configuration = __configuration_dict__[module_name](
                    self.configuration
                )
            )
        )

    '''
    '''
    def get(self, api_name, filter="", **kwargs):
        return __package_dict__[api_name]()

    def get_all_clients(self, filter="", **kwargs):
        """
        Fetches the list of API client names registered with
        this SDK. The names are to be used as keys to fetch
        the actual client, using the #get method, to invoke
        the API operations.

        TODO Implement the optional filters
        :param filter:
        :param kwargs:
        :return: The list of all API clients names, without printing the banner.
        """
        return __package_dict__.keys()

    def list(self, filter="", **kwargs):
        '''
        Prints a banner to the console, followed by the list of
        API clients available with this SDK.

        :param filter:
        :param kwargs:
        :return:
        '''
        print(" _____    ____      _      ")
        print("|_   _|  / ___|    / \     ")
        print("  | |   | |       / _ \    ")
        print("  | |   | |___   / ___ \   ")
        print("  |_|    \____| /_/   \_\  ")
        print("                           ")
        print(" ____  ____  _  __     ______   _______ _   _  ___  _   _ ")
        print("/ ___||  _ \| |/ /    |  _ \ \ / /_   _| | | |/ _ \| \ | |")
        print("\___ \| | | | ' /_____| |_) \ V /  | | | |_| | | | |  \| |")
        print(" ___) | |_| | . \_____|  __/ | |   | | |  _  | |_| | |\  |")
        print("|____/|____/|_|\_\    |_|    |_|   |_| |_| |_|\___/|_| \_|")
        print("                           ")
        print(str(__package_dict__).replace(',', ',\n'))
        print("                                                             ")
        print(" _____ _____ _____ _____ _____ _____ _____ _____ _____ _____ ")
        print("|_____|_____|_____|_____|_____|_____|_____|_____|_____|_____|")
        print("                           ")
        print("                           ")
