"""
# Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
# VMware Confidential
Author: banerjees@vmware.com
"""
from tca.api.client.tca_configuration import TCAConfiguration
from tca.api.client.rest import RESTClientObject, ApiException

class SessionManager(object):
    def __init__(self):
        self.configuration = TCAConfiguration()
        self._api_key = {}

    '''
    '''
    def set_configuration(self, configuration):
        self.configuration = configuration

    def lg(self):
        return self.configuration.lg()

    def login(self, *args, **kwargs):
        pass

class HybriditySessionManager(SessionManager):
    def __init__(self):
        super().__init__()
        self.lg().debug("---------[ Initializing Hybridity SessionManager ]--------")

    '''
    '''
    def login(self, *args, **kwargs):
        self.lg().info("[SM] GETTING IN TOUCH WITH YOUR SERVER: %s", self.configuration.server)
        self.lg().debug("[SM] Fetching TCA Auth... with User= %s", self.configuration.username)
        version = "1.0"
        if 'version' in kwargs:
            version = kwargs['version']
        self.__fetch_hybridity_token_if_invalid(version, *args, **kwargs)
        if 'api_key' in kwargs:
            kwargs['api_key'].update(self._api_key)
        self.lg().debug("[SM] DONE Fetching TCA Auth... with User=%s %s", self.configuration.username, " and Pass=")
        return self._api_key

    '''
    '''
    def __fetch_hybridity_token_if_invalid(self, version, *args, **kwargs):  # noqa: E501
        """
        Fetches hybridity token, if expired
        """

        force_renew = True if 'force_renew' in kwargs and kwargs['force_renew'] else False
        if not force_renew and self._validate_session_based_on_token(version, **kwargs):
            self.lg().info("[SM] Session Token Valid; Not renewing!")
            return

        self.lg().debug("[SM] Session Token Invalid/Expired; Renewing...")
        params = locals()
        header_params = {}
        version = '1.0'
        if 'version' in params:
            version = params['version']
            header_params['Version'] = params['version']  # noqa: E501
        header_params['Accept'] = "application/json"
        header_params['Content-Type'] = "application/json"
        form_params = []
        local_var_files = {}

        '''
        JSON Body
        '''
        body_params = {}
        body_params['username'] = self.configuration.username
        body_params['password'] = self.configuration.password
        body_params['version'] = version

        hy_rest_client = RESTClientObject(configuration=self.configuration)
        auth_resp = hy_rest_client.POST(url=self.configuration.server + '/hybridity/api/sessions',
                                         body=body_params,
                                         headers=header_params)

        self._api_key['x-hm-authorization'] = auth_resp.getheaders()['x-hm-authorization']
        self.lg().debug("[SM] HY Auth RESP [H]: %s", auth_resp.getheaders()['x-hm-authorization'])
        self.lg().debug("[SM] From the caller: ApiKey: %s", args)
        return self._api_key

    '''
    '''
    def _validate_session_based_on_token(self, version, **args):
        """
        Validates Hybridity session
        :return: bool
        """

        if 'x-hm-authorization' not in self._api_key.keys():
            self.lg().debug("[SM] NO Auth Token found!")
            return False

        params = locals()
        header_params = {}

        if 'version' in params:
            header_params['Version'] = params['version']  # noqa: E501
        header_params['Accept'] = "application/json"
        header_params['x-hm-authorization'] = self._api_key['x-hm-authorization']

        hy_rest_client = RESTClientObject(configuration=self.configuration)
        try:
            auth_resp = hy_rest_client.GET(url=self.configuration.server + '/hybridity/api/session',
                headers=header_params)
        except ApiException:
            self.lg().debug("[SM] Session Expired!")
            return False

        return True


'''
To be used for HTTP Basic Auth
'''
class NoOpSessionManager(SessionManager):
    """
    To be used for HTTP Basic Auth
    """
    def __init__(self):
        super().__init__()
        self.lg().debug("---------[ Initializing NoOp SessionManager ]--------")

    '''
    '''
    def login(self, *args, **kwargs):
        return self._api_key