# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: dpallagolla@vmware.com
"""

from __future__ import absolute_import

import unittest

from api.client.sdk_manager import SDKManager
from api.client.session_manager import HybriditySessionManager
from caas_v2_addon import Addon, AddonMetadata, AddonSpec, AddonSpecClusterRef, AddonSpecConfig
from cluster import ClustersQueryBody
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestAddonApi(unittest.TestCase):
    """AddonApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')      # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)                 # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.caas_addon_client = self.sdk_manager.get_api('tca.caas_v2_addon:AddonApi')
        self.cluster_client = self.sdk_manager.get_api('tca.cluster:ClusterApi')

    def tearDown(self):
        pass

    def test_create_addon(self):
        workload_cluster_name = ''
        mgmt_cluster_name = ''
        add_on_name = ''
        harbor_extension_id = ''
        tca_cp_id = self.get_hcxuuid_for_mgmt_cluster(mgmt_cluster_name=mgmt_cluster_name)

        add_on_metadata = AddonMetadata(name=add_on_name, cluster_name=workload_cluster_name)

        cluster_ref = AddonSpecClusterRef(name=workload_cluster_name, namespace=workload_cluster_name)
        config = AddonSpecConfig(partner_system_refs=[harbor_extension_id])
        add_on_spec = AddonSpec(name=add_on_name, cluster_ref=cluster_ref, config=config)
        add_on_payload = Addon(metadata=add_on_metadata, spec=add_on_spec)

        self.caas_addon_client.create_addon(add_on_payload, cluster_name=workload_cluster_name,
                                            mgmt_cluster_name=mgmt_cluster_name,
                                            tca_cp_id=tca_cp_id)

    def get_hcxuuid_for_mgmt_cluster(self, mgmt_cluster_name):
        mgmt_cluster_filter = ClustersQueryBody(filter={"clusterName": mgmt_cluster_name})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=mgmt_cluster_filter)
        mgmt_cluster = cluster_infra_cluster_query_response[0]
        return mgmt_cluster.hcx_uuid

    def test_delete_addon(self):
        """Test case for delete_addon

        API to delete Addon like multus, vsphere-csi etc. on Kubernetes Cluster  # noqa: E501
        """
        pass

    def test_get_addon(self):
        """Test case for get_addon

        API to get Addon like multus, vsphere-csi etc. created on Kubernetes Cluster  # noqa: E501
        """
        pass

    def test_get_addons(self):
        """Test case for get_addons

        API to fetch all Addons like multus, vsphere-csi etc. created on Kubernetes Cluster  # noqa: E501
        """
        pass

    def test_update_addon(self):
        """Test case for update_addon

        API to update Addon like multus, vsphere-csi etc. on Kubernetes Cluster  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
