# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: ngoutham@vmware.com

"""

from __future__ import absolute_import

import unittest

import tca.tcfm
from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.tcfm import CsrDetails, SigningAuthority
from tca.tcfm.api.certificate_management_api import \
    CertificateManagementApi  # noqa: E501
from tca.tcfm.rest import ApiException
from tca.tcfm.api_client import ApiClient
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.tcfm.configuration import Configuration as Cfg  # VMW010


class TestCertificateManagementApi(unittest.TestCase):
    """CertificateManagementApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server(
            'https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)  # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.client = self.sdk_manager.get_api('tca.tcfm:CertificateManagementApi')
        print(
            "[Test-CertificateManagementApi] Fetched CertificateManagementApi CLIENT: ",
            self.client)

    def tearDown(self):
        pass

    def test_create_signing_authority(self):
        """Test case for create_signing_authority

        Create Certificate Signing Authority  # noqa: E501
        """
        csrDetails = CsrDetails(country="US", organization="VMWARE",
                                organization_unit="SEBU", state="CA",
                                key_size=2048, algorithm='RSA',
                                email_address="test@vmware.com", locality=None)
        body = SigningAuthority(name="sdk-test", type="selfsign", valid_for_days=1,
                                csr_details=csrDetails)
        self.client.create_signing_authority(body, async_req=False)
        pass

    def test_download_csrs(self):
        """Test case for download_csrs

        Download CSR for appliances  # noqa: E501
        """
        pass

    def test_get_appliances(self):
        """Test case for get_appliances

        Get Certificate Management Appliances  # noqa: E501
        """
        pass

    def test_get_signing_authorities(self):
        """Test case for get_signing_authorities

        Get all Certificate Signing Authorities  # noqa: E501
        """
        response = self.client.get_signing_authorities(async_req=False)
        print(response)
        pass

    def test_get_signing_authority(self):
        """Test case for get_signing_authority

        Get Certificate Signing Authorities of type  # noqa: E501
        """
        response = self.client.get_signing_authority(name="sdk-test", async_req=False)
        print(response)
        pass

    def test_manage_certificates(self):
        """Test case for manage_certificates

        Certificate Management Input  # noqa: E501
        """
        pass

    def test_retry_failed_certificate_operation(self):
        """Test case for retry_failed_certificate_operation

        Retry failed certificate management task/s  # noqa: E501
        """
        pass

    def test_upload_certificates(self):
        """Test case for upload_certificates

        upload certificate to appliance  # noqa: E501
        """
        pass

    def test_upload_server_certificate(self):
        """Test case for upload_server_certificate

        upload server certificate for Cloud Native TCA and TCA-CP  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
