# coding: utf-8

"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: banerjees@vmware.com
"""

from __future__ import absolute_import

import unittest

import tca.system_management
from tca.system_management import AdminCertificatesBody
from tca.system_management.api.certificates_api import CertificatesApi  # noqa: E501
from tca.system_management.rest import ApiException
from tca.system_management.api_client import ApiClient
from tca.system_management.configuration import Configuration as Cfg  # VMW010
from tca.api.client.session_manager import NoOpSessionManager
from tca.api.client.tca_configuration import TCAConfiguration
from tca.api.client.sdk_manager import SDKManager


class TestCertificatesApi(unittest.TestCase):
    """CertificatesApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server(
            'https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('admin_login')
        tca_config.set_password('***********')
        tca_config.set_verify_ssl(False)  # Insecure: only for NFV functional validation

        sessionmgr = NoOpSessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(sessionmgr)

        self.system_mgmt_client = self.sdk_manager.get_api(
            'tca.system_management:CertificatesApi')
        print("[Test-Admin] Fetched ADMIN API CLIENT: ", self.system_mgmt_client)

    def tearDown(self):
        pass

    def test_api_admin_certificates_get(self):
        """Test case for api_admin_certificates_get

        Get list of trusted certificates  # noqa: E501
        """
        certs = self.system_mgmt_client.api_admin_certificates_get(
            accept='application/json', async_req=False)


    def test_api_admin_certificates_post(self):
        """Test case for api_admin_certificates_post

        Import trusted certificate  # noqa: E501
        """
        body = AdminCertificatesBody(
        certificate="-----BEGIN CERTIFICATE-----\nMIIDjjCCAnYlIOpnjANBgkqhkiG9w0BAQsF"
                        "ADCBiDELMAkGA1UEBhMC\nVVMxEzARBb3JuaWExCzAJBgNVBAcMAkNBMQ8w"
                        "DQYDVQQKDAZW\nTXdhcmUxdflUxEzARBgNVBAMMCnZtd2FyZS5jb20xIjAg"
                        "Bgkq\nhkiG9w0BCQEWE25nwefwjb20wHhcNMjIwNDAxMDYwNjU0WhcN\nMj"
                        "IwNTAxMDYwNjU0WjCBMCVVMxEzARBgNVBAgMCkNhbGlmb3Ju\naWExCzAJB"
                        "gNVBAcMAkNBMQ8wDQwefwefweffNVBAsMBFNFQlUx\nEzARBgNVBAMMCnZt"
                        "d2FyZS5jb20xIjAgBgkqwfwwefaGFtQHZt\nd2FyZS5jb20wggEiMA0GCSq"
                        "GSIb3DQEBAQUAwefwfuH//QJp46\nAeAaqn/2UwBciN4uYV6PEmu/yGnWeH"
                        "qA8jqJQGZwefwfewfwi\nqL9+AQ2k43bedGMT/fFIdIjqmYeUiKYOboUw7+"
                        "vXW8SLqwefpc\nshLWMVli2PIyb6yrgrTAFpdq96QS62s9whllSc1lTUfAb"
                        "JazdKn06qvYWdHzsTqM\nhcALwwefwefwefwQX8/o2a+o15f8qfH/13FTRl"
                        "Rpx5Msp1GDVjI\nP752PTWwefwefweweim7mEAVLRmi2aDoO2wYSKs76ai2"
                        "Bgvk7gA\nAOVxdj4wefwwfIhvcNAQELBQADggEBAAzdFVa+m4PDwzyPztqu"
                        "\neMsjIO5Trs+jwefwefwefwefwT94y5kWUbtJwFk3F/FsNmXwoz\nGsRTt"
                        "XTni7GAf6cfcClwfwfwfwfwfwfwfwfu6UFvmdGbEyweAe\nCJfCvibL0m1L"
                        "IjVtf0dpNwr234rf23rwfwElwouQAhpJwM0La\n6ZJsJejIdt/HYNmRnZXJ"
                        "toUIj+QXpzwef43rfds4rf0cTFfY9b\nFT8eCcinqRwei0+UdREcaL1ZS6RR"
                        "NifHQDDHB9sdf+p1y0atpH3ol8u\nBV0=\n-----END CERTIFICATE-----")
        response = self.system_mgmt_client.\
            api_admin_certificates_post(body,accept="application/json",
                                             content_type="application/json",
                                             async_req=False)
        print(response)
        pass

    def test_api_admin_certificates_server_certificate_appliance_manager_put(self):
        """Test case for api_admin_certificates_server_certificate_appliance_manager_put

        To change the appliance management certificate  # noqa: E501
        """
        pass

    def test_api_admin_certificates_server_certificate_httpd_put(self):
        """Test case for api_admin_certificates_server_certificate_httpd_put

        Import Server certificate  # noqa: E501
        """
        pass

    def test_api_admin_certificates_sha256_delete(self):
        """Test case for api_admin_certificates_sha256_delete

        Delete trusted certificate  # noqa: E501
        """
        response = self.system_mgmt_client.api_admin_certificates_sha256_delete(
            accept="application/json", content_type="application/json",
            sha256="***sha256***", async_req=False)
        print(response)
        pass


if __name__ == '__main__':
    unittest.main()
