# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import unittest

from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.cluster import ClustersQueryBody
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestClusterApi(unittest.TestCase):
    """ClusterApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.cluster_client = self.sdk_manager.get_api('tca.cluster:ClusterApi')
        print("[Test-cluster] Fetched CLUSTER CLIENT: ", self.cluster_client)


    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.cluster:ClusterApi').list()

    def test_get_k8_cluster(self):
        """Test case for get_k8_cluster

        """

        cluster_get_response = self.cluster_client.get_k8_cluster(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Cluster get Response: ", cluster_get_response)
        pass

    def test_infra_cluster_query(self):
        """Test case for infra_cluster_query

        Api to query Kubernetes Cluster for Telco Cloud Automation  # noqa: E501
        """

        filter = ClustersQueryBody(filter={"clusterType": "Workload"})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=filter)
        print("infra cluster query Response: ", cluster_infra_cluster_query_response)
        pass

    def test_undeploy_infra(self):
        """Test case for undeploy_infra

        """

        cluster_delete_response = self.cluster_client.undeploy_infra(cluster_id='2ced900b-a8b7-4917-96bb-22753c1bccff')
        print("Cluster delete Response: ", cluster_delete_response)
        pass


if __name__ == '__main__':
    unittest.main()
