# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import unittest

from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.cluster import ClusterConfigurations, ClusterNetworks, ClusterMasterNodes, ClusterWorkerNodes
from tca.clustertemplate import ClusterTemplate, ClusterTemplateClusterConfigCni, ClusterTemplateClusterConfigCsi, \
    ClusterTemplateClusterConfigProperties, ClusterTemplateConfig, ClusterTemplateConfigCpuManagerPolicy

from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestClusterTemplatesApi(unittest.TestCase):
    """ClusterTemplatesApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)  # Insecure: only for NFV functional validation
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.cluster_template_client = self.sdk_manager.get_api('tca.clustertemplate:ClusterTemplatesApi')
        print("[Test-cluster-template] Fetched CLUSTER TEMPLATE CLIENT: ", self.cluster_template_client)

    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.clustertemplate:ClusterTemplatesApi').list()

    def test_create_cluster_template(self):
        """Test case for create_cluster_template

        Api to create a cluster template for Telco Cloud Automation  # noqa: E501
        """

        # Management cluster template
        cluster_config = ClusterConfigurations(kubernetes_version="v1.21.8+vmware.1")
        networkmodel = []
        networkmodel.append(ClusterNetworks(label='MANAGEMENT'))
        master_node = []
        master_node.append(
            ClusterMasterNodes(name='master', storage=50, cpu=8, memory=16384, replica=3, networks=networkmodel))
        worker_nodes = []
        worker_nodes.append(ClusterWorkerNodes(name='np1', replica=2, labels=[], memory=16384, cpu=8, storage=80,
                                               networks=networkmodel))
        body = ClusterTemplate(name="sdk-test-management", cluster_type='MANAGEMENT', cluster_config=cluster_config,
                               master_nodes=master_node, worker_nodes=worker_nodes, description="sdk-check", tags=[])

        cluster_template_create = self.cluster_template_client.create_cluster_template(body)
        print("Cluster template create response: ", cluster_template_create)

        # WORKLOAD cluster template
        cni = []
        cni.append(ClusterTemplateClusterConfigCni(name='calico'))
        csi = []
        csi.append(ClusterTemplateClusterConfigCsi(name='vsphere-csi',
                                                   properties=ClusterTemplateClusterConfigProperties(name="vsphere-sc",
                                                                                                     timeout="300",
                                                                                                     is_default=True)))
        cluster_config = ClusterConfigurations(kubernetes_version="v1.21.8+vmware.1", csi=csi, cni=cni)
        body = {}
        body['config'] = ClusterTemplateConfig(
            cpu_manager_policy=ClusterTemplateConfigCpuManagerPolicy(policy='default', type='kubernetes'))  # noqa: E501

        worker_nodes = []
        worker_nodes.append(
            ClusterWorkerNodes(name='np1', replica=2, labels=["sdk=wc"], memory=16384, cpu=8, storage=80,
                               networks=networkmodel))
        body = ClusterTemplate(name="sdk-test-workload", cluster_type='WORKLOAD', cluster_config=cluster_config,
                               master_nodes=master_node, worker_nodes=worker_nodes, description="sdk-check", tags=[])

        cluster_template_create = self.cluster_template_client.create_cluster_template(body)
        print("Cluster template create response: ", cluster_template_create)

        print("created cluster template id: {}".format(cluster_template_create.id))
        pass

    def test_download_cluster_template(self):
        """Test case for download_cluster_template

        Api to download a cluster template for Telco Cloud Automation  # noqa: E501
        """

        cluster_template_download = self.cluster_template_client.download_cluster_template(
            id='')  # example id='b09657f7-4412-48b8-bc26-c4efa5a1927e'
        print("Cluster download: ", cluster_template_download)
        pass

    def test_update_cluster_template(self):
        """Test case for update_cluster_template

        Api to update a cluster template for Telco Cloud Automation  # noqa: E501
        """

        # WORKLOAD cluster template
        networkmodel = []
        networkmodel.append(ClusterNetworks(label='MANAGEMENT'))
        master_node = []
        master_node.append(
            ClusterMasterNodes(name='master', storage=50, cpu=8, memory=16384, replica=3, networks=networkmodel))
        worker_nodes = []
        worker_nodes.append(ClusterWorkerNodes(name='np1', replica=2, labels=[], memory=16384, cpu=8, storage=80,
                                               networks=networkmodel))

        cni = []
        cni.append(ClusterTemplateClusterConfigCni(name='calico'))
        csi = []
        csi.append(ClusterTemplateClusterConfigCsi(name='vsphere-csi',
                                                   properties=ClusterTemplateClusterConfigProperties(name="vsphere-sc",
                                                                                                     timeout="300",
                                                                                                     is_default=True)))
        cluster_config = ClusterConfigurations(kubernetes_version="v1.21.8+vmware.1", csi=csi, cni=cni)
        body = {}
        body['config'] = ClusterTemplateConfig(
            cpu_manager_policy=ClusterTemplateConfigCpuManagerPolicy(policy='default', type='kubernetes'))  # noqa: E501

        worker_nodes = []
        worker_nodes.append(
            ClusterWorkerNodes(name='np1', replica=2, labels=["sdk=wc"], memory=16384, cpu=8, storage=80,
                               networks=networkmodel))
        body = ClusterTemplate(name="sdk-test-workload", cluster_type='WORKLOAD', cluster_config=cluster_config,
                               master_nodes=master_node, worker_nodes=worker_nodes, description="sdk-check-update",
                               tags=[])
        self.body = body

        cluster_template_update = self.cluster_template_client.update_cluster_template(body=body,
                                                                                       id='')  # example id='b09657f7-4412-48b8-bc26-c4efa5a1927e'
        print("Cluster template update response: ", cluster_template_update)
        pass

    def test_upload_cluster_template(self):
        """Test case for upload_cluster_template

        Api to upload a cluster template for Telco Cloud Automation  # noqa: E501
        """

        # data = '/Users/gaarurnathan/Desktop/sdk_files/sdk_upload.json'
        # cluster_template_upload = self.cluster_template_client.upload_cluster_template(file=data)
        # print("Cluster upload response: ", cluster_template_upload)
        pass


if __name__ == '__main__':
    unittest.main()
