# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import unittest


from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.infra import InfraRequirementsFilter
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestCnfCatalogInfraRequirementsApi(unittest.TestCase):
    """CnfCatalogInfraRequirementsApi unit test stubs"""

    def setUp(self):

        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.infra_client = self.sdk_manager.get_api('tca.infra:CnfCatalogInfraRequirementsApi')
        print("[Test-cluster] Fetched INFRA CLIENT: ", self.infra_client)


    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.infra:CnfCatalogInfraRequirementsApi').list()

    def test_get_infra_requirement_params(self):
        """Test case for get_infra_requirement_params

        """
        body = InfraRequirementsFilter()
        print(body)
        get_infra_requirement_response = self.infra_client.get_infra_requirement_params(body=body)
        print("Get infra requirement Response: ", get_infra_requirement_response)
        pass

    def test_get_infra_requirement_supported_kernel_versions(self):
        """Test case for get_infra_requirement_supported_kernel_versions

        """

        get_infra_requiremnent_supported_version_response = self.infra_client.get_infra_requirement_supported_kernel_versions()
        print("Get infra requirement and supported Response: ", get_infra_requiremnent_supported_version_response)
        pass

    def test_update_infra_requirement_supported_kernel_versions(self):
        """Test case for update_infra_requirement_supported_kernel_versions

        """

        update_infra_requiremnent_supported_version_response = self.infra_client.update_infra_requirement_supported_kernel_versions()
        print("update infra requirement and supported Response: ", update_infra_requiremnent_supported_version_response)
        pass


if __name__ == '__main__':
    unittest.main()
