# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import base64
import unittest

from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.svnfm import CreateSvnfmExtension, ExtensionInterfaceInfo


class TestExtensionApi(unittest.TestCase):
    """ExtensionApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.extension_client = self.sdk_manager.get_api('tca.svnfm:ExtensionApi')
        print("[Test-Extension] Fetched EXTENSION CLIENT: ", self.extension_client)

    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.svnfm:ExtensionApi').list()

    def test_create_extension(self):
        """Test case for create_extension

        """

        # password encoding
        newcred = 'Harbor12345'
        messageBytes = newcred.encode('ascii')
        base64bytes = base64.b64encode(messageBytes)
        newcred_encode = base64bytes.decode('ascii')

        access_info = {}
        access_info['username'] = 'admin'
        access_info['password'] = newcred_encode

        vim = []
        viminfo = {}
        viminfo["vimSystemUUID"] = "vmware_923CFF07C2CC4503937A33F9D9B508D3"
        viminfo["vimName"] = 'sdkwc'
        viminfo["vimId"] = '414D31747C20427CB0BB50980CB8B76F'
        vim.append(viminfo)

        interface_info = ExtensionInterfaceInfo(url="http://10.196.228.223/", trusted_certificates='',
                                                description='sdk_extension')
        body = CreateSvnfmExtension(vim_info=vim, name='SDK-harbor', extension_subtype='Harbor', version="v1.x",
                                    access_info=access_info, type='Repository', interface_info=interface_info,additional_parameters={})
        print(body)
        create_extension_response = self.extension_client.create_extension(body=body)
        print("Create extension response: ", create_extension_response)
        pass

    def test_create_svnfm_extension(self):
        """Test case for create_svnfm_extension

        """
        pass

    def test_delete_extension(self):
        """Test case for delete_extension

        """

        delete_extension_response = self.extension_client.delete_extension(
            extension_id='bab4691c-a86c-4bbd-8625-a66b0fee2ac2')
        print("Delete extension response: ", delete_extension_response)
        pass

    def test_edit_extension(self):
        """Test case for edit_extension

        """
        pass

    def test_edit_svnfm_extension(self):
        """Test case for edit_svnfm_extension

        """
        pass

    def test_get_extension(self):
        """Test case for get_extension

        """

        get_extension_response = self.extension_client.get_extension(
            extension_id='bab4691c-a86c-4bbd-8625-a66b0fee2ac2')
        print("Get extension response: ", get_extension_response)
        pass

    def test_get_extension_subtype(self):
        """Test case for get_extension_subtype

        """

        get_extension_subtype_response = self.extension_client.get_extension_subtype(extension_subtype='true')
        print("Get extension subtype response: ", get_extension_subtype_response)
        pass

    def test_get_extensions(self):
        """Test case for get_extensions

        """

        get_extension_response = self.extension_client.get_extensions()
        print("Get extensions response: ", get_extension_response)
        pass

    def test_get_extensions_type(self):
        """Test case for get_extensions_type

        """

        get_extensions_type_response = self.extension_client.get_extensions_type()
        print("Get extensions type response: ", get_extensions_type_response)
        pass

    def test_get_svnfm_packages(self):
        """Test case for get_svnfm_packages

        """

        get_svnfm_packages_response = self.extension_client.get_svnfm_packages(extension_id='118b0aaf-3f59-4ba8-846b-da1432fe1b78')
        print("Get svnfm packages response: ", get_svnfm_packages_response)
        pass

    def test_get_svnfm_vnf_instances(self):
        """Test case for get_svnfm_vnf_instances

        """

        get_svnfm_vnf_instances_response = self.extension_client.get_svnfm_vnf_instances(
            extension_id='118b0aaf-3f59-4ba8-846b-da1432fe1b78')
        print("Get svnfm instance response: ", get_svnfm_vnf_instances_response)
        pass

    def test_register_svnfm_packages(self):
        """Test case for register_svnfm_packages

        """
        pass


if __name__ == '__main__':
    unittest.main()
