# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: dpallagolla@vmware.com
"""

from __future__ import absolute_import

import unittest

from cluster import ClustersQueryBody
from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestGenericCrApi(unittest.TestCase):

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')      # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)                 # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.generic_cr_api_client = self.sdk_manager.get_api('tca.caas_k8s_generic_cr:GenericCrApi')
        self.cluster_client = self.sdk_manager.get_api('tca.cluster:ClusterApi')

    def tearDown(self):
        pass

    def test_get_tca_bom_release(self):
        """Test case for get_tca_bom_release

        Api to get a TCA BOM release with a given name  # noqa: E501
        """
        pass

    def test_get_workload_cluster_kube_config(self):
        workload_cluster_name = ''
        mgmt_cluster_name = ''
        tca_cp_id = self.get_hcxuuid_for_mgmt_cluster(mgmt_cluster_name=mgmt_cluster_name)
        workload_cluster_kubeconfig = self.generic_cr_api_client.get_workload_cluster_kube_config(
            workload_cluster_name=workload_cluster_name,
            secret_name=workload_cluster_name + '-kubeconfig',
            mgmt_cluster_name=mgmt_cluster_name, tca_cp_id=tca_cp_id)
        print("For cluster ", workload_cluster_name, "kubeconfig is:%s", workload_cluster_kubeconfig)

    def get_hcxuuid_for_mgmt_cluster(self, mgmt_cluster_name):
        mgmt_cluster_filter = ClustersQueryBody(filter={"clusterName": mgmt_cluster_name})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=mgmt_cluster_filter)
        mgmt_cluster = cluster_infra_cluster_query_response[0]
        return mgmt_cluster.hcx_uuid

    def test_list_tca_bom_releases(self):
        mgmt_cluster_filter = ClustersQueryBody(filter={"clusterType": "MANAGEMENT"})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=mgmt_cluster_filter)

        cluster = cluster_infra_cluster_query_response[0]
        mgmt_cluster_name = cluster.cluster_name
        tca_cp_id = cluster.hcx_uuid

        tca_bom_list = self.generic_cr_api_client.list_tca_bom_releases(tca_cp_id=tca_cp_id,
                                                                        mgmt_cluster_name=mgmt_cluster_name)
        print("For cluster ", mgmt_cluster_name, " TCA BOM list is:%s", tca_bom_list)


if __name__ == '__main__':
    unittest.main()
