# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import base64
import unittest

from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.cluster import ClusterSpecNetworks, ClusterSpecMasterNodes, ClusterSpecWorkerNodes, ClusterPlacementParams, \
    ClusterRequest, ClusterConfigurationsCsi, ClusterConfigurationsProperties, NodePool, ClusterConfigCpuManagerPolicy, \
    ClusterConfigCpuManagerPolicyProperties, IdChangePasswordBody, Filter, ClusterUpgradeRequest, Cluster, \
    ClusterConfigurations, ClusterConfigurationsCni, ClusterConfigurationsTools

from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestInfraApi(unittest.TestCase):
    """InfraApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.cluster_client = self.sdk_manager.get_api('tca.cluster:InfraApi')
        print("[Test-cluster] Fetched CLUSTER CLIENT: ", self.cluster_client)

        self.clusterclient = self.sdk_manager.get_api('tca.cluster:ClusterApi')
        print("[Test-cluster] Fetched CLUSTER CLIENT: ", self.cluster_client)

    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.cluster:InfraApi').list()

    def test_abort_cluster_operation(self):
        """Test case for abort_cluster_operation

        """

        cluster = self.cluster_client.abort_cluster_operation(operation_id='8e63d73c-2754-452d-9b46-8b25df080966')
        print("Abort cluster operation response: ", cluster)
        pass

    def test_change_cluster_password(self):
        """Test case for change_cluster_password

        Api to edit Cluster password  # noqa: E501
        """

        # password encoding
        newcred = 'password'
        messageBytes = newcred.encode('ascii')
        base64bytes = base64.b64encode(messageBytes)
        newcred_encode = base64bytes.decode('ascii')

        oldcred = 'password'
        messageBytes = oldcred.encode('ascii')
        base64bytes = base64.b64encode(messageBytes)
        oldcred_encode = base64bytes.decode('ascii')

        body = IdChangePasswordBody(cluster_password=newcred_encode, existing_cluster_password=oldcred_encode)
        print(body)
        cluster = self.cluster_client.change_cluster_password(id='2736d800-e189-474c-bb5c-d3ddac21ac3b', body=body)
        print("cluster password change response: ", cluster)
        pass

    def test_create_cluster_node_pool(self):
        """Test case for create_cluster_node_pool

        """

        conf = ClusterConfigCpuManagerPolicy(policy='default', type='kubernetes')
        config = {}
        config['cpuManagerPolicy'] = conf
        print(config)
        placement_params = []
        placement_params.append(ClusterPlacementParams(type='Folder', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='Datastore', name='vsanDatastore-CL02'))
        placement_params.append(ClusterPlacementParams(type='ResourcePool', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='ClusterComputeResource', name='Dev-CL02'))
        networkmodel = []
        network = ClusterSpecNetworks(label='MANAGEMENT',
                                      network_name="/Dev-Physical-DC/network/CaaS-Airgap/VLAN614-VMPG-CL02",
                                      nameservers=['10.112.0.1'], mtu="")
        networkmodel.append(network)
        body = NodePool(placement_params=placement_params, replica=2, memory=16384, cpu=8, storage=80, name='sdknp',
                        networks=networkmodel, labels=["test=sdk"], config=config)
        print(body)
        cluster = self.cluster_client.create_cluster_node_pool(body=body,
                                                               cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Cluster create node pool response: ", cluster)
        pass

    def test_delete_node_pool(self):
        """Test case for delete_node_pool

        """

        cluster = self.cluster_client.delete_node_pool(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b',
                                                       node_pool_id='9868ec83-37f1-4d66-9f2d-0442ccf381b3')
        print("Cluster delete node pool response: ", cluster)
        pass

    def test_deploy_cluster(self):
        """Test case for deploy_cluster

        Api to deploy Kubernetes Cluster for Telco Cloud Automation  # noqa: E501
        """
        # password encoding
        creds = 'password'
        messageBytes = creds.encode('ascii')
        base64bytes = base64.b64encode(messageBytes)
        authDatabase64 = base64bytes.decode('ascii')

        networkmodel = []
        network = ClusterSpecNetworks(label='MANAGEMENT',
                                      network_name="/Dev-Physical-DC/network/CaaS-Airgap/VLAN614-VMPG-CL02",
                                      nameservers=['10.112.0.1'], mtu="")
        networkmodel.append(network)
        master_node = []
        master_node.append(ClusterSpecMasterNodes(name='master', networks=networkmodel))
        worker_nodes = []
        worker_nodes.append(ClusterSpecWorkerNodes(name='np1', networks=networkmodel))
        placement_params = []
        placement_params.append(ClusterPlacementParams(type='Folder', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='Datastore', name='vsanDatastore-CL02'))
        placement_params.append(ClusterPlacementParams(type='ResourcePool', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='ClusterComputeResource', name='Dev-CL02'))
        body = ClusterRequest(cluster_type='MANAGEMENT', cluster_password=authDatabase64,
                              hcx_cloud_url='https://10.202.228.168',
                              cluster_template_id='4354f655-c97d-4abf-8048-b37ec923e8d3',
                              vm_template='/Dev-Physical-DC/vm/name/photon-3-kube-v1.21.8-vmware.1-tkg.2-49e70fcb8bdd006b8a1cf7823484f98f-19330261',
                              name='sdkmc'
                              , endpoint_ip='10.202.226.234', placement_params=placement_params,
                              master_nodes=master_node, worker_nodes=worker_nodes)

        # cluster = self.cluster_client.deploy_cluster(body)
        # print("Cluster deploy response: ", cluster)

        # workload cluster
        networkmodel = []
        network = ClusterSpecNetworks(label='MANAGEMENT',
                                      network_name="/Dev-Physical-DC/network/CaaS-Airgap/VLAN614-VMPG-CL02",
                                      nameservers=['10.112.0.1'], mtu="")
        networkmodel.append(network)
        master_node = []
        master_node.append(ClusterSpecMasterNodes(name='master', networks=networkmodel))
        worker_nodes = []
        worker_nodes.append(ClusterSpecWorkerNodes(name='np1', networks=networkmodel))
        placement_params = []
        placement_params.append(ClusterPlacementParams(type='Folder', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='Datastore', name='vsanDatastore-CL02'))
        placement_params.append(ClusterPlacementParams(type='ResourcePool', name='SDK-test'))
        placement_params.append(ClusterPlacementParams(type='ClusterComputeResource', name='Dev-CL02'))
        body = ClusterRequest(cluster_type='WORKLOAD', cluster_password=authDatabase64,
                              hcx_cloud_url='https://10.202.228.168',
                              cluster_template_id='aade127b-12b1-48b9-9fb9-2158e3dcdf54',
                              vm_template='/Dev-Physical-DC/vm/name/photon-3-kube-v1.21.8-vmware.1-tkg.2-49e70fcb8bdd006b8a1cf7823484f98f-19330261',
                              name='sdkwc'
                              , endpoint_ip='10.202.226.235', placement_params=placement_params,
                              master_nodes=master_node, worker_nodes=worker_nodes,
                              management_cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3',
                              cluster_config=ClusterConfigurationsCsi(name='vsphere-csi',
                                                                      properties=ClusterConfigurationsProperties(
                                                                          region="tca-k8s-region",
                                                                          zone='tca-k8s-region')))
        cluster = self.cluster_client.deploy_cluster(body)
        print("Cluster deploy response: ", cluster)
        pass

    def test_edit_cluster(self):
        """Test case for edit_cluster

        Api to edit a cluster for Telco Cloud Automation  # noqa: E501
        """
        cluster_get_response = self.clusterclient.get_k8_cluster(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Cluster get Response: ", cluster_get_response)

        # create body using Cluster() model or edit the required value from cluster_get_response
        # body = Cluster(id='2736d800-e189-474c-bb5c-d3ddac21ac3b',cluster_name='sdkwc',cluster_type='WORKLOAD',management_cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3',vsphere_cluster_name='Dev-CL02',
        #                hcx_uuid=cluster_get_response.hcx_uuid,cluster_password=cluster_get_response.cluster_password,cluster_template=cluster_get_response.cluster_template,
        #                placement_params=cluster_get_response.placement_params)
        # print(body)

        cluster_get_response.master_nodes[0].replica = 3
        print(cluster_get_response)
        cluster = self.cluster_client.edit_cluster(body=cluster_get_response,
                                                   cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("edit cluster response: ", cluster)
        pass

    def test_edit_cluster_config(self):
        """Test case for edit_cluster_config

        Api to edit cluster config  # noqa: E501
        """

        cni = ClusterConfigurationsCni(name='calico')
        cnilist = []
        cnilist.append(cni)
        csilist = []
        csi = ClusterConfigurationsCsi(name='vsphere-csi',
                                       properties=ClusterConfigurationsProperties(
                                           region="tca-k8s-region",
                                           zone='tca-k8s-region'))
        tools = ClusterConfigurationsTools(name='nodeconfig-operator', version='2.0.1-19350428')
        toolslist = []
        toolslist.append(tools)
        tools = ClusterConfigurationsTools(name='helm', version='2.17.0')
        toolslist.append(tools)
        csilist.append(csi)
        print(csi)
        body = ClusterConfigurations(csi=csilist, tools=toolslist, cni=cnilist)
        print(body)
        cluster = self.cluster_client.edit_cluster_config(body=body, cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Edit cluster config response: ", cluster)
        pass

    def test_edit_node_pool(self):
        """Test case for edit_node_pool

        Api to edit a node pool  # noqa: E501
        """

        networkmodel = []
        network = ClusterSpecNetworks(label='MANAGEMENT',
                                      network_name="/Dev-Physical-DC/network/CaaS-Airgap/VLAN614-VMPG-CL02",
                                      nameservers=['10.112.0.1'])
        networkmodel.append(network)
        print(networkmodel)
        body = NodePool(name='npplugtest1', storage=80, replica=4, networks=networkmodel, cpu=8, memory=16384,
                        labels=['task=plugtest', "check=add"])  # noqa: E501
        cluster = self.cluster_client.edit_node_pool(node_pool_id='e2e6f0f9-7fb5-4743-b7a4-ba824ed412ed',
                                                     cluster_id='2d16a687-dcc2-4e37-b024-561e4a44371f', body=body)
        print("Cluster node pool edit response: ", cluster)
        pass

    def test_genereate_spec(self):
        """Test case for genereate_spec

        """

        cluster = self.cluster_client.genereate_spec(cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3',
                                                     action='generateSpec')
        print("Cluster spec: ", cluster)
        pass

    def test_get_cluster_config(self):
        """Test case for get_cluster_config

        """

        cluster = self.cluster_client.get_cluster_config(cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3')
        print("Cluster config: ", cluster)
        pass

    def test_get_clusters(self):
        """Test case for get_clusters

        """

        cluster = self.cluster_client.get_clusters()
        print("Get clusters response: ", cluster)
        pass

    def test_get_clusters_node_pools(self):
        """Test case for get_clusters_node_pools

        """

        cluster = self.cluster_client.get_clusters_node_pools(cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3')
        print("Get cluster node pool response: ", cluster)
        pass

    def test_get_k8_cluster_node_pool(self):
        """Test case for get_k8_cluster_node_pool

        """

        cluster = self.cluster_client.get_k8_cluster_node_pool(cluster_id='1180c0ed-87de-4510-8e83-0eef2e83a8d3',
                                                               node_pool_id='1bf05924-8a1f-4f11-b193-983b7e26d5a0')
        print("Get k8s cluster node pool response: ", cluster)
        pass

    def test_get_node_pool_customization(self):
        """Test case for get_node_pool_customization

        """

        cluster = self.cluster_client.get_node_pool_customization(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b',
                                                                  node_pool_id='0871796a-22d8-4216-9faf-09995df93900')
        print("Get node pool customization response: ", cluster)
        pass

    def test_kuberenetes_version_upgrade_matrix(self):
        """Test case for kuberenetes_version_upgrade_matrix

        Api to get the K8s versions upgrade matrix for Telco Cloud Automation  # noqa: E501
        """

        body = Filter()
        cluster = self.cluster_client.kuberenetes_version_upgrade_matrix(body=body)
        print("Kuberenetes version upgrade matrix: ", cluster)
        pass

    def test_pause_node_pool(self):
        """Test case for pause_node_pool

        Pause a Nodepool in a cluster  # noqa: E501
        """

        cluster = self.cluster_client.pause_node_pool(cluster_id='2d16a687-dcc2-4e37-b024-561e4a44371f',
                                                      node_pool_id='e2e6f0f9-7fb5-4743-b7a4-ba824ed412ed')
        print("Pause node pool response: ", cluster)
        pass

    def test_retry_cluster_operation(self):
        """Test case for retry_cluster_operation

        """

        cluster = self.cluster_client.retry_cluster_operation(operation_id="f796fe17-480f-49c7-8a22-3092ff08c781")
        print("retry operation response: ", cluster)
        pass

    def test_supported_kubernetes_versions(self):
        """Test case for supported_kubernetes_versions

        Api to get all the supported  K8s versions of cluster for Telco Cloud Automation  # noqa: E501
        """

        cluster = self.cluster_client.supported_kubernetes_versions()
        print("Supported kubernetes version response: ", cluster)
        pass

    def test_sync_esx_info(self):
        """Test case for sync_esx_info

        Api to sync Esx Info for Workload Clusters on demand  # noqa: E501
        """

        cluster = self.cluster_client.sync_esx_info(id='2d16a687-dcc2-4e37-b024-561e4a44371f')
        print("sync esx response: ", cluster)
        pass

    def test_unpause_node_pool(self):
        """Test case for unpause_node_pool

        Unpause a Nodepool in a cluster  # noqa: E501
        """

        cluster = self.cluster_client.unpause_node_pool(cluster_id='2d16a687-dcc2-4e37-b024-561e4a44371f',
                                                        node_pool_id='e2e6f0f9-7fb5-4743-b7a4-ba824ed412ed')
        print("Unpause node pool response: ", cluster)
        pass

    def test_upgrade_cluster(self):
        """Test case for upgrade_cluster

        Api to upgrade K8s version of Cluster for Telco Cloud Automation  # noqa: E501
        """
        body = ClusterUpgradeRequest(kubernetes_version="v1.21.8+vmware.1",
                                     vm_template='/Dev-Physical-DC/vm/name/photon-3-kube-v1.21.8-vmware.1-tkg.2-49e70fcb8bdd006b8a1cf7823484f98f-19330261')
        cluster = self.cluster_client.upgrade_cluster(id='2736d800-e189-474c-bb5c-d3ddac21ac3b', body=body)
        print("Upgrade cluster response: ", cluster)
        pass

    def test_upgrade_cluster_addon(self):
        """Test case for upgrade_cluster_addon

        Api to upgrade addons on the cluster (for workload cluster only)  # noqa: E501
        """

        cluster = self.cluster_client.upgrade_cluster_addon(id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Upgrade cluster addon response: ", cluster)
        pass

    def test_upgrade_history(self):
        """Test case for upgrade_history

        Api to get the K8s versions upgrade history of cluster for Telco Cloud Automation  # noqa: E501
        """

        cluster = self.cluster_client.upgrade_history(id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("Upgrade cluster history response: ", cluster)
        pass

    def test_upgrade_node_pool(self):
        """Test case for upgrade_node_pool

        """

        cluster = self.cluster_client.upgrade_node_pool(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b',
                                                        node_pool_id='0871796a-22d8-4216-9faf-09995df93900')
        print("Upgrade node pool response: ", cluster)
        pass

    def test_validate_upgrade_cluster(self):
        """Test case for validate_upgrade_cluster

        Api to validate  K8s version upgrade of Cluster for Telco Cloud Automation  # noqa: E501
        """

        cluster = self.cluster_client.upgrade_node_pool(cluster_id='2736d800-e189-474c-bb5c-d3ddac21ac3b',
                                                        node_pool_id='0871796a-22d8-4216-9faf-09995df93900')
        print("Upgrade node pool response: ", cluster)
        pass

    def test_vsphere_csi_zone_support(self):
        """Test case for vsphere_csi_zone_support

        Api to verify whether vsphere csi zone support is present.  # noqa: E501
        """

        cluster = self.cluster_client.vsphere_csi_zone_support(id='2736d800-e189-474c-bb5c-d3ddac21ac3b')
        print("vsphere csi zone support response: ", cluster)
        pass


if __name__ == '__main__':
    unittest.main()
