# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: dpallagolla@vmware.com
"""

from __future__ import absolute_import

import ast
import unittest

from api.client.sdk_manager import SDKManager
from api.client.session_manager import HybriditySessionManager
from caas_v2_nodepool import Nodepool, NodepoolMetadata, NodepoolSpec, NodepoolSpecCloudMachineTemplate, \
    NodepoolSpecCloudMachineTemplateVSphereMachine, NodepoolSpecTcaBomReleaseRef, NodepoolSpecNetwork, \
    NodepoolSpecNetworkDevices, NodepoolSpecKubeadmConfigTemplate, NodepoolSpecKubeadmConfigTemplateJoinConfiguration, \
    NodepoolSpecKubeadmConfigTemplateJoinConfigurationNodeRegistration, NodepoolSpecCloudProvider
from cluster import ClustersQueryBody
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005


class TestNodePoolApi(unittest.TestCase):
    """NodePoolApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')      # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)                 # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.nodepool_api_client = self.sdk_manager.get_api('tca.caas_v2_nodepool:NodePoolApi')
        self.generic_cr_api = self.sdk_manager.get_api('tca.caas_k8s_generic_cr:GenericCrApi')
        self.cluster_client = self.sdk_manager.get_api('tca.cluster:ClusterApi')

    def tearDown(self):
        pass

    def test_create_node_pool(self):
        workload_cluster_name = 'test-cluster'
        self.mgmt_cluster_name = ''
        self.kubernetes_version_for_cluster = 'v1.20.15'

        nodepool_metadata = NodepoolMetadata(name=workload_cluster_name + '-np1')
        vim_id = ''
        datacenter = ''
        resource_pool = ''
        datastore = ''
        storage_policy_name = ''
        folder = ''
        template = ''
        network_name = ''
        name_servers = []
        vsphere_machine = NodepoolSpecCloudMachineTemplateVSphereMachine(datacenter=datacenter,
                                                                         resource_pool=resource_pool,
                                                                         datastore=datastore,
                                                                         storage_policy_name=storage_policy_name,
                                                                         folder=folder, template=template)
        cloud_machine_template = NodepoolSpecCloudMachineTemplate(v_sphere_machine=vsphere_machine)
        tca_bom_release_ref = self.build_tca_bom_release_ref()
        devices = NodepoolSpecNetworkDevices(dhcp4=True, network_name=network_name, nameservers=name_servers)
        network = NodepoolSpecNetwork(devices=[devices])

        kubelet_extra_args = {'cpu-manager-policy': 'static', 'system-reserved': 'cpu=1,memory=1Gi'}
        node_registration = NodepoolSpecKubeadmConfigTemplateJoinConfigurationNodeRegistration(
            kubelet_extra_args=kubelet_extra_args)
        join_configuration = NodepoolSpecKubeadmConfigTemplateJoinConfiguration(node_registration=node_registration)
        kube_admin_config_template = NodepoolSpecKubeadmConfigTemplate(join_configuration=join_configuration)
        cloud_provider = NodepoolSpecCloudProvider(vim_id=vim_id)
        spec = NodepoolSpec(clone_mode='linkedClone', cloud_machine_template=cloud_machine_template,
                            cluster_name=workload_cluster_name, disk_gi_b=30, memory_mi_b=8192, num_cp_us=8,
                            tca_bom_release_ref=tca_bom_release_ref, network=network,
                            kubeadm_config_template=kube_admin_config_template, cloud_provider=cloud_provider)

        nodepool_payload = Nodepool(metadata=nodepool_metadata, spec=spec)
        tca_cp_id = self.get_hcxuuid_for_mgmt_cluster(mgmt_cluster_name=self.mgmt_cluster_name)
        self.nodepool_api_client.create_node_pool(nodepool_payload, cluster_name=workload_cluster_name,
                                  mgmt_cluster_name=self.mgmt_cluster_name,tca_cp_id=tca_cp_id)

    def build_tca_bom_release_ref(self):

        mgmt_cluster_filter = ClustersQueryBody(filter={"clusterName": self.mgmt_cluster_name})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=mgmt_cluster_filter)

        mgmt_cluster = cluster_infra_cluster_query_response[0]
        mgmt_cluster_name = mgmt_cluster.cluster_name
        tca_cp_id = mgmt_cluster.hcx_uuid
        self.tca_cp_id = tca_cp_id

        tca_bom_list = self.generic_cr_api.list_tca_bom_releases(tca_cp_id=tca_cp_id,
                                                                 mgmt_cluster_name=mgmt_cluster_name)
        items = ast.literal_eval(tca_bom_list)["items"]
        tca_bom_ref = None
        for item in items:
            if self.kubernetes_version_for_cluster in item['metadata']['name']:
                tca_bom_ref = item
                break
        tca_bom_ref_name = tca_bom_ref['metadata']['name']

        return NodepoolSpecTcaBomReleaseRef(name=tca_bom_ref_name)

    def get_hcxuuid_for_mgmt_cluster(self, mgmt_cluster_name):
        mgmt_cluster_filter = ClustersQueryBody(filter={"clusterName": mgmt_cluster_name})
        cluster_infra_cluster_query_response = self.cluster_client.infra_cluster_query(body=mgmt_cluster_filter)
        mgmt_cluster = cluster_infra_cluster_query_response[0]
        return mgmt_cluster.hcx_uuid

    def test_delete_node_pool(self):
        """Test case for delete_node_pool

        Api to delete Kubernetes Nodepool for Telco Cloud Automation  # noqa: E501
        """
        pass

    def test_edit_node_pool(self):
        """Test case for edit_node_pool

        Api to modify Kubernetes Nodepool for Telco Cloud Automation  # noqa: E501
        """
        pass

    def test_get_all_node_pools(self):
        """Test case for get_all_node_pools

        API to fetch all node pools created on Kubernetes Cluster  # noqa: E501
        """
        pass

    def test_get_node_pool(self):
        """Test case for get_node_pool

        API to get Node Pool created on a Kubernetes Cluster  # noqa: E501
        """
        pass

    def test_get_node_pool_customization(self):
        """Test case for get_node_pool_customization

        API to get Node Pool Customization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
