# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: gaarurnathan@vmware.com
"""

from __future__ import absolute_import

import unittest

from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.vnfpm_v1 import StatsFilter, PmJobRequest, PmJobCriteria


class TestPerformanceManagementApi(unittest.TestCase):
    """PerformanceManagementApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.performance_mgmt_client = self.sdk_manager.get_api('tca.vnfpm_v1:PerformanceManagementApi')
        print("[Test-Performance] Fetched PERFORMANCE MGMT CLIENT: ", self.performance_mgmt_client)

    def tearDown(self):
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.vnfpm_v1:PerformanceManagementApi').list()

    def test_create_pm_job(self):
        """Test case for create_pm_job

         Create Performance Management Job for reporting on given object Ids  # noqa: E501
        """
        criteria = PmJobCriteria(performance_metric=["VcpuUsageMeanVnf", "VdiskReadUsageMeanVnf", "VdiskWriteUsageMeanVnf", "VmemoryUsageMeanVnf", "ByteIncomingVnfCP", "ByteOutgoingVnfCP", "PacketIncomingVnfCP", "PacketOutgoingVnfCP"],collection_period=60,reporting_period=300,reporting_boundary="02-24-2022-17-22")
        body = PmJobRequest(pm_job_name='SDKjob',object_type='VNF',object_ids=["03956daf-8fa9-4f8a-9e53-e10d13c1b3cf"],pm_job_criteria=criteria)
        create_pm_job_response = self.performance_mgmt_client.create_pm_job(body=body)
        print("Create pm job Response: ", create_pm_job_response)
        pass

    def test_delete_pm_job(self):
        """Test case for delete_pm_job

         Delete existing Performance Management Job and reports  # noqa: E501
        """

        delete_pm_job_response = self.performance_mgmt_client.delete_pm_job(pm_job_id='7efa1cad-be63-4591-b348-f0b93b8ed724')
        print("Delete pm job Response: ", delete_pm_job_response)
        pass

    def test_get_pm_job(self):
        """Test case for get_pm_job

         Query existing Performance Management Job for reporting  # noqa: E501
        """

        get_pm_job_response = self.performance_mgmt_client.get_pm_job(pm_job_id='f04525ba-6f2e-43e6-b55e-b9bbd676c238')
        print("Get pm job Response: ", get_pm_job_response)
        pass

    def test_get_pm_job_report(self):
        """Test case for get_pm_job_report

         Query existing Performance Management Job reports  # noqa: E501
        """

        get_pm_job_report_response = self.performance_mgmt_client.get_pm_job_report(pm_job_id='f04525ba-6f2e-43e6-b55e-b9bbd676c238',report_id='57986365-c98e-42f9-9735-b848cfb79696')
        print("Get pm job report Response: ", get_pm_job_report_response)
        pass

    def test_get_all_pm_jobs(self):
        """Test case for get_all_pm_jobs

         listing all pm jobs  # noqa: E501
        """

        list_all_pm_job_response = self.performance_mgmt_client.get_all_pm_jobs()
        print("List all pm jobs Response: ", list_all_pm_job_response)
        pass

    def test_download_report_file(self):
        """Test case for download_report_file

        Download available Performance Management Job report file  # noqa: E501
        """

        download_report_file_response = self.performance_mgmt_client.download_report_file(
            pm_job_id='d4d900c8-9f84-47f0-9428-6dd768977d01', report_id='fb497a64-3934-40bb-a771-33036b28a529')
        print("Download report file Response: ", download_report_file_response)
        pass

    def test_query_inventory_stats(self):
        """Test case for query_inventory_stats

        Get Stats from Vms given the vdu Id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
