# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: ngoutham@vmware.com
"""

from __future__ import absolute_import

import unittest

import tca.system_management
from tca.api.client.sdk_manager import SDKManager
from tca.api.client.session_manager import NoOpSessionManager
from tca.system_management import SystemTimesettingsBody
from tca.system_management.api.time_api import TimeApi  # noqa: E501
from tca.system_management.rest import ApiException
from tca.system_management.api_client import ApiClient
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.system_management.configuration import Configuration as Cfg  # VMW010


class TestTimeApi(unittest.TestCase):
    """TimeApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server(
            'https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('admin_login')
        tca_config.set_password('***********')
        tca_config.set_verify_ssl(False)  # Insecure: only for NFV functional validation

        sessionmgr = NoOpSessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(sessionmgr)

        self.system_mgmt_client = self.sdk_manager.get_api(
            'tca.system_management:TimeApi')
        print("[Test-Admin] Fetched ADMIN API CLIENT: ", self.system_mgmt_client)

    def tearDown(self):
        pass

    def test_system_timesettings_get(self):
        """Test case for system_timesettings_get

        Get Time Settings (NTP, Date & Timezone)  # noqa: E501
        """
        ntpdate = self.system_mgmt_client.system_timesettings_get(
            accept="application/json", async_req=False)
        print(ntpdate)
        pass

    def test_system_timesettings_ntp_delete(self):
        """Test case for system_timesettings_ntp_delete

        Remove NTP Settings  # noqa: E501
        """
        pass

    def test_system_timesettings_put(self):
        """Test case for system_timesettings_put

        Configure Time Settings (NTP, Date & Timezone)  # noqa: E501
        """
        body = SystemTimesettingsBody(ntp_server=['ntp1.eng.vmware.com'],
                                      _datetime='04/07/2022 11:49:35',
                                      timezone='UTC')
        response = self.system_mgmt_client. \
            system_timesettings_put(body,
                                    accept="application/json",
                                    async_req=False,
                                    content_type="application/json")
        print(response)


if __name__ == '__main__':
    unittest.main()
