# coding: utf-8

"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: banerjees@vmware.com
"""

from __future__ import absolute_import

import unittest

import tca.troubleshooting
from tca.troubleshooting.api.troubleshooting_api import TroubleshootingApi  # noqa: E501
from tca.troubleshooting.rest import ApiException
from tca.troubleshooting.api_client import ApiClient
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.sdk_manager import SDKManager
from tca.nfv_vim_v1 import RegisterVim, RegisterVimResponse, Vim, VimList
from tca.troubleshooting import TechSupportGlobalSettings, TechSupportConfig

class TestTroubleshootingApi(unittest.TestCase):
    """TroubleshootingApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')      # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)                 # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        session_manager = hybridity_sessionmgr

        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(session_manager)

        self.t_api = self.sdk_manager.get_api('tca.troubleshooting:TroubleshootingApi')
        self.s_api = self.sdk_manager.get_api('tca.troubleshooting:SupportApi')

    def tearDown(self):
        pass

    def test_print_api_banner(self):
        self.sdk_manager.list()
        pass

    def test_print_all_operations(self):
        self.sdk_manager.get('tca.troubleshooting:TroubleshootingApi').list()
        self.sdk_manager.get('tca.troubleshooting:SupportApi').list()
        pass

    def test_get_settings(self):
        """Test case for get_settings
        """
        tech_support_global_settings = self.t_api.get_settings()
        print("Tech-Support Global Settings: ", tech_support_global_settings)
        pass

    def test_get_task_details(self):
        """Test case for get_task_details

        """
        job_id = '66498f48-85ec-4623-8d7d-1278dc646a92'
        print("Job Id: ", job_id)
        task = self.t_api.get_task_details(task_id=job_id)
        print("Modify Resp: ", task)
        pass

    def test_request_tech_support_logs(self):
        """Test case for request_tech_support_logs

        """
        request_body = TechSupportConfig(
            collect_nsp_tech_bundle=False,
            collect_mongo_dump=True)
        task = self.t_api.request_tech_support_logs(action='collectTechSupportBundle', body=request_body)
        print("Tech-Support Task: ", task)
        pass

    def test_update_settings(self):
        """Test case for update_settings

        """
        update_body = TechSupportGlobalSettings(auto_acknowledge=False)
        ret = self.t_api.update_settings(body=update_body)
        print("Update Settings Response: ", ret)
        pass

    def test_get_system_details(self):
        """
        Test to get the system details from Tech-Support
        """
        system_details = self.s_api.get_system_details()
        print("System Details: ", system_details)


if __name__ == '__main__':
    unittest.main()
