# coding: utf-8

"""
   Copyright (c) 2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: banerjees@vmware.com
"""

from __future__ import absolute_import

import unittest

import tca.nfv_vim_v1
from tca.nfv_vim_v1.api.vim_api import VIMApi  # noqa: E501
from tca.nfv_vim_v1.rest import ApiException
from tca.nfv_vim_v1.api_client import ApiClient
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.nfv_vim_v1.configuration import Configuration as Cfg # VMW010
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.sdk_manager import SDKManager
from tca.nfv_vim_v1 import RegisterVim, RegisterVimResponse, Vim, VimList

class TestVIMApi(unittest.TestCase):
    """VIMApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')      # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        global session_manager
        session_manager = hybridity_sessionmgr

        global sdk_manager
        sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(session_manager)

        self.api = sdk_manager.get_api('tca.nfv_vim_v1:VIMApi')

        # Some IDs used across the tests
        global vim_id
#        vim_id = vim_id if vim_id is not None else None

    def tearDown(self):
        pass

    def test_print_api_banner(self):
        sdk_manager.list()
        pass

    def test_print_all_operations(self):
        sdk_manager.get('tca.nfv_vim_v1:VIMApi').list()
        pass

    def test_get_tenants(self):
        """Test case for get_tenants
        """
        vim_id = 'vmware_75EDF5914FBF40E2AAE92129A87D8A45'
        tenants = self.api.get_tenants(vim_id)
        print("VIM Tenants: ", tenants)
        pass

    def test_get_vims(self):
        """Test case for get_vims
        """
        vims = self.api.get_vims()
        vim_id = vims.items[0].vim_id
        print("VIMs: ", vims)
        print("VIM_ID: ", vim_id)
        pass

    def test_modify_vim(self):
        """Test case for modify_vim

        """
        modify_body = RegisterVim()
        modify_body.hcx_cloud_url = 'https://10.202.228.168'
        modify_body.vim_name = 'work-cluster-cnftest-sdk-1'
        modify_body.cluster_name = 'clusterwithmtu'
        modify_body.auth_type = 'kubeconfig'
        # Base64 Encoded Kubeconfig Content
        modify_body.kubeconfig = 'BASE64ENCODEDKUBECONFIG0='
        #RegisterVimResponse
        resp = self.api.modify_vim(tenant_id='D926285F102B46FC9F5FD7DF7367CEF0', body=modify_body)
        print("Modify Resp: ", resp)
        print("Modify Resp Class: ", resp.__class__.__name__)
        pass

    def test_register_vim(self):
        """Test case for register_vim

        """
        register_body = RegisterVim()
        register_body.hcx_cloud_url = 'https://10.202.228.168'
        register_body.vim_name = 'work-cluster-cnftest-sdk-2'
        register_body.cluster_name = 'clusterwithmtu'
        register_body.auth_type = 'kubeconfig'
        # Base64 Encoded Kubeconfig Content
        register_body.kubeconfig = 'BASE64ENCODEDKUBECONFIG0='
        # RegisterVimResponse
        resp = self.api.register_vim(body=register_body)
        print("Modify Resp: ", resp)
        print("Modify Resp Class: ", resp.__class__.__name__)
        pass

    def test_remove_vim(self):
        """Test case for remove_vim

        """
        self.api.remove_vim(tenant_id='D926285F102B46FC9F5FD7DF7367CEF0')
        pass


if __name__ == '__main__':
    unittest.main()
