# coding: utf-8
"""
   Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
   VMware Confidential
   Author: banerjees@vmware.com
"""

from __future__ import absolute_import

import unittest

from tca.vnfpkgm import CreateVnfPkgInfoRequest, VnfPkgInfoUserDefinedData, VnfPkgInfoUserDefinedDataTags
from tca.api.client.tca_configuration import TCAConfiguration
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.sdk_manager import SDKManager

class TestVnfCatalogApi(unittest.TestCase):
    """VnfCatalogApi unit test stubs"""

    def setUp(self):
        self.created_vnfd_id = None
        tca_config = TCAConfiguration()
        tca_config.set_server('https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(True)
        tca_config.cert_file = "/com/vmware/sdk-trials/sdk-py/cert.pem"
        tca_config.key_file = "/com/vmware/sdk-trials/sdk-py/key.pem"
        tca_config.ssl_ca_cert = "/com/vmware/sdk-trials/sdk-py/ca_cert.pem"
        tca_config.assert_hostname = False

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.vnfpkgm_client = self.sdk_manager.get_api('tca.vnfpkgm:VnfCatalogApi')
        print("[Test-catalog] Fetched VNFPKGM CLIENT: ", self.vnfpkgm_client)

        self.nsdm_client = self.sdk_manager.get_api('tca.nsdm:DefaultApi')
        print("[Test-catalog] Fetched NSDM CLIENT: ", self.nsdm_client)

    def tearDown(self):
        pass

    def test_get_all_clients_from_sdk_manager(self):
        self.sdk_manager.list()
        pass

    def test_get_operations_for_a_given_client_in_sdk(self):
        self.sdk_manager.get('tca.vnfpkgm:VnfCatalogApi').list()
        pass

    def test_get_all_vnf_descriptors(self):
        """Test case for get_all_vnf_descriptors
        Query VNF packages information.
        """
        print("\n------------------- TRYING AGAIN WITH API2 ------------------")
        descriptors = self.vnfpkgm_client.get_all_vnf_descriptors(
            '2.7.1',
            accept='application/json')
        print("Descriptors-VNF: ", descriptors)
        pass

    def test_get_all_ns_descriptors(self):
        print("\n------------------- TRYING AGAIN WITH NSDM API ------------------")
        descriptors_nsdm = self.nsdm_client.ns_descriptors_get(
            '2.7.1',
            accept='application/json')
        print("Descriptors-NS: ", descriptors_nsdm)
        pass

    def test_create_vnf_descriptor(self):
        """Test case for create_vnf_descriptor

        Create a new individual VNF package resource.  # noqa: E501
        """
        body = CreateVnfPkgInfoRequest()
        body.user_defined_data = VnfPkgInfoUserDefinedData(name="test-vcpuGrantDisabled-sdk-003", tags=[])
        self.vnfpkg = self.vnfpkgm_client.create_vnf_descriptor(body, "2.7.1", accept="application/json",
                                                           content_type="application/json")
        print("New VNF-Package: ", self.vnfpkg)
        self.created_vnfd_id = vnfpkg.id
        pass

    def test_upload_vnf_descriptor(self):
        """Test case for upload_vnf_descriptor

        Upload a VNF package by providing the content of the VNF package.  # noqa: E501
        """

        created = self.vnfpkgm_client.get_all_vnf_descriptors(
            '2.7.1',
            accept='application/json',
            filter='(eq,user_defined_data/name,test-vcpuGrantDisabled-sdk-003)')
        self.created_vnfd_id = created[0].id
        if self.created_vnfd_id is None:
            raise Exception("vnfd_id not found!")

        self.vnfpkgm_client.upload_vnf_descriptor("2.7.1",
              accept="application/json",
              vnf_pkg_id=self.created_vnfd_id,
              content_type="multipart/form-data",
              file="~/InadequateVcpuGrantDisabled.csar")
        pass

    def test_download_vnf_descriptor(self):
        """Test case for download_vnf_descriptor

        Fetch an on-boarded VNF package.  # noqa: E501
        """
        pass

    def test_get_vnf_descriptor(self):
        """Test case for get_vnf_descriptor

        Read information about an individual VNF package.  # noqa: E501
        """
        pass

    def test_get_vnfd_model(self):
        """Test case for get_vnfd_model

        Read VNFD of an on-boarded VNF package.  # noqa: E501
        """
        pass

    def test_subscriptions_get(self):
        """Test case for subscriptions_get

        Query multiple subscriptions.  # noqa: E501
        """
        pass

    def test_subscriptions_post(self):
        """Test case for subscriptions_post

        Subscribe to notifications related to on-boarding and/or changes of VNF packages.  # noqa: E501
        """
        pass

    def test_subscriptions_subscription_id_delete(self):
        """Test case for subscriptions_subscription_id_delete

        Terminate a subscription.  # noqa: E501
        """
        pass

    def test_subscriptions_subscription_id_get(self):
        """Test case for subscriptions_subscription_id_get

        Read an individual subscription resource.  # noqa: E501
        """
        pass

    def test_update_vnf_catalog(self):
        """Test case for update_vnf_catalog

        Update information about an individual VNF package.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
