# coding: utf-8

"""
    Copyright (c) 2021-2022 VMware, Inc. All rights reserved.
    VMware Confidential
    Author: ngoutham@vmware.com
"""

from __future__ import absolute_import

import unittest

import tca.nfv_vim_v1
from tca.nfv_vim_v1.api.vim_api import VIMApi  # noqa: E501
from tca.nfv_vim_v1.rest import ApiException
from tca.nfv_vim_v1.api_client import ApiClient
from tca.api.client.tca_configuration import TCAConfiguration  # VMW005
from tca.nfv_vim_v1.configuration import Configuration as Cfg  # VMW010
from tca.api.client.session_manager import HybriditySessionManager
from tca.api.client.sdk_manager import SDKManager
from tca.nfv_vim_v1 import RegisterVim, RegisterVimResponse, Vim, VimList
from tca.ns_lcm_v1 import NsInstantiateAdditionalParamsExtCps, \
    NsInstantiateAdditionalParamsExtVirtualLinks
from tca.vnflcm import CreateVnfRequest, MetaData,VnfInstantiateRequestAdditionalParams,\
    VduParam, VimConnectionInfo, \
    VimConnectionInfoExtras, InstantiateVnfRequest, ScaleVnfRequestAdditionalParams, \
    ScaleVnfRequest, \
    TerminateVnfRequestAdditionalParams, TerminateVnfRequest


class TestVnfInatantiateApi(unittest.TestCase):
    """VIMApi unit test stubs"""

    def setUp(self):
        tca_config = TCAConfiguration()
        tca_config = TCAConfiguration()
        tca_config.set_server(
            'https://tca_server')  # Ensure no trailing slash '/' in the tca_server
        tca_config.set_username('tenant@vsphere.local')
        tca_config.set_password('********************')
        tca_config.set_verify_ssl(False)  # Insecure: only for NFV functional validation

        hybridity_sessionmgr = HybriditySessionManager()
        self.sdk_manager = SDKManager(). \
            with_configuration(tca_config). \
            with_session_manager(hybridity_sessionmgr)

        self.client = self.sdk_manager.get_api('tca.vnflcm:DefaultApi')
        print("[Test-vnflcmDefaultApi] Fetched vnflcmDefaultApi CLIENT: ", self.client)

    def tearDown(self):
        pass

    def test_vnf_instances_get(self):
        print("Test : test_vnf_instances_get")
        body = CreateVnfRequest(vnfd_id="nfd_226693ca-96b3-4e04-8eb5-b26c2e3cdea8",
                                vnf_instance_name="test-sdk-python"
                                , vnf_instance_description="sdk test vnf instantiation",
                                metadata=MetaData(tags=[], extension_id=None))
        response = self.client.vnf_instances_post(body, accept="application/json",
                                                  content_type="application/json",
                                                  version="2.7.1", async_req=False)
        print(response)

    def test_vnf_instances_vnf_instance_id_instantiate_post(self):
        print("Test : test_vnf_instances_vnf_instance_id_instantiate_post")
        extcps = [NsInstantiateAdditionalParamsExtCps(cpd_id="ext-vdu1", cp_config=[]),
                  NsInstantiateAdditionalParamsExtCps(cpd_id="ext-vdu2", cp_config=[])]
        extvirtuallinks = NsInstantiateAdditionalParamsExtVirtualLinks(id=0,
                                                resource_id="dvportgroup-8712",
                                                network_name="CaaS-Uplink-612",
                                                xt_cps=extcps)
        vduparams = [VduParam(vdu_name="vdu1",
                       deployment_profile_id="45010e8b-1122-4a95-91d3-c057824f1127"),
                     VduParam(vdu_name="vdu2",
                       deployment_profile_id="45010e8b-1122-4a95-91d3-c057824f1127")]
        additionalparams = VnfInstantiateRequestAdditionalParams(vdu_params=vduparams,
                                                      lcm_interfaces=None,
                                                      entity_prefix="",
                                                      use_v_app_templates=False,
                                                      catalog_name=None,
                                                      catalog_id=None,
                                                      skip_grant=False,
                                                      ignore_grant_failure=None,
                                                      disable_auto_rollback=None,
                                                      isable_grant=None,
                                                      skip_node_customization=None,
                                                      is_vnf_v_app_template=False,
                                                      v_app_template_name=None,
                                                      storage_profiles=None)
        vimconnectioninfo = VimConnectionInfo(
            id="vmware_75EDF5914FBF40E2AAE92129A87D8A45", vim_type="",
            extra=VimConnectionInfoExtras(
                deployment_profile_id="45010e8b-1122-4a95-91d3-c057824f1127"))
        body = InstantiateVnfRequest(flavour_id="default", instantiation_level_id=None,
                                     ext_virtual_links=[extvirtuallinks],
                                     ext_managed_virtual_links=None,
                                     vim_connection_info=[vimconnectioninfo],
                                     localization_language=None,
                                     additional_params=additionalparams, extensions=None,
                                     vnf_configurable_properties=None)
        response = self.client. \
            vnf_instances_vnf_instance_id_instantiate_post(body,
                                  accept="application/json",
                                  content_type="application/json",
                                  version="2.7.1",
                                  vnf_instance_id='24185c4b-97ff-4985-af17-7e83846ee519',
                                  async_req=False);
        print(response)

    def test_vnf_instances_vnf_instance_id_scale_post(self):
        print("Test : test_vnf_instances_vnf_instance_id_scale_post")
        additionalparams = ScaleVnfRequestAdditionalParams(vdu_params=[],
                                                           lcm_interfaces=[])
        body = ScaleVnfRequest(type="SCALE_OUT", aspect_id="aspect_0", number_of_steps=1,
                               additional_params=additionalparams)
        response = self.client.vnf_instances_vnf_instance_id_scale_post(body,
                             accept="application/json",content_type="application/json",
                             version="2.7.1",
                             vnf_instance_id='24185c4b-97ff-4985-af17-7e83846ee519',
                             async_req=False);
        print(response)

    def test_vnf_instances_vnf_instance_id_terminate_post(self):
        print("Test : test_vnf_instances_vnf_instance_id_terminate_post")
        additionalparams = TerminateVnfRequestAdditionalParams(lcm_interfaces=[])
        body = TerminateVnfRequest(termination_type="GRACEFUL",
                                   graceful_termination_timeout=120,
                                   additional_params=additionalparams)
        response = self.client.vnf_instances_vnf_instance_id_terminate_post(body,
                                accept="application/json",
                                content_type="application/json",
                                version="2.7.1",
                                vnf_instance_id='24185c4b-97ff-4985-af17-7e83846ee519',
                                async_req=False)
        print(response)

    def test_vnf_instances_vnf_instance_id_delete(self):
        print("Test : test_vnf_instances_vnf_instance_id_delete")
        data = self.client.vnf_instances_vnf_instance_id_delete(
            vnf_instance_id='24185c4b-97ff-4985-af17-7e83846ee519', version="2.7.1",
            async_req=False)
        print(data)

    def test_vnf_instances_vnf_instance_id_get(self):
        response = self.client.vnf_instances_vnf_instance_id_get(
            vnf_instance_id='24185c4b-97ff-4985-af17-7e83846ee519',
            accept="application/json",
            content_type="application/json", version="2.7.1",
            async_req=False)
        print(response)


if __name__ == '__main__':
    unittest.main()
